<?php

class LodgixServiceDB {

    function __construct() {
        global $wpdb;
        $this->db = $wpdb;
        $prefix = $wpdb->prefix;
        $this->tableProperties = $prefix . LodgixConst::TABLE_PROPERTIES;
        $this->tableLangProperties = $prefix . LodgixConst::TABLE_LANG_PROPERTIES;
        $this->tableAmenities = $prefix . LodgixConst::TABLE_AMENITIES;
        $this->tableLangAmenities = $prefix . LodgixConst::TABLE_LANG_AMENITIES;
        $this->tablePictures = $prefix . LodgixConst::TABLE_PICTURES;
        $this->tableMergedRates = $prefix . LodgixConst::TABLE_MERGED_RATES;
        $this->tableRules = $prefix . LodgixConst::TABLE_RULES;
        $this->tablePages = $prefix . LodgixConst::TABLE_PAGES;
        $this->tableLangPages = $prefix . LodgixConst::TABLE_LANG_PAGES;
        $this->tablePolicies = $prefix . LodgixConst::TABLE_POLICIES;
        $this->tableTaxes = $prefix . LodgixConst::TABLE_TAXES;
        $this->tableFees = $prefix . LodgixConst::TABLE_FEES;
        $this->tableDeposits = $prefix . LodgixConst::TABLE_DEPOSITS;
        $this->tableReviews = $prefix . LodgixConst::TABLE_REVIEWS;
        $this->tableLinkRotators = $prefix . LodgixConst::TABLE_LINK_ROTATORS;
        $this->tableLanguages = $prefix . LodgixConst::TABLE_LANGUAGES;
        $this->tableSearchableAmenities = $prefix . LodgixConst::TABLE_SEARCHABLE_AMENITIES;
    }

    function create() {
        $this->createTable($this->tableProperties,
            "`id` int(10) unsigned NOT NULL,
            `owner_id` int(10) unsigned,
            `description` varchar(255) default NULL,
            `description_long` text,
            `details` text,
            `main_image` varchar(255) default NULL,
            `main_image_thumb` varchar(255) default NULL,
            `address` varchar(500) default NULL,
            `city` varchar(100) default NULL,
            `zip` varchar(10) default NULL,
            `state_code` varchar(2) default NULL,
            `country_code` varchar(2) default NULL,
            `bedrooms` smallint(6) default '0',
            `bathrooms` float default '0',
            `minrate` float default '0',
            `maxrate` float default '0',
            `min_daily_rate` float default '0',
            `min_weekly_rate` float default '0',
            `min_monthly_rate` float default '0',        
            `sleeps` smallint(6) default '0',
            `smoking` tinyint(1) default '0',
            `pets` tinyint(1) default '0',
            `children` tinyint(1) default '0',
            `rates` text,
            `proptype` varchar(255) default NULL,
            `latitude` double default '-1',
            `longitude` double default '-1',
            `contact` varchar(255) default NULL,
            `phone_local` varchar(50) default NULL,
            `phone_free_toll` varchar(50) default NULL,
            `email` varchar(255) default NULL,
            `serving_status` tinyint(1) default '1',
            `deleted` smallint(6) default '0',
            `date_created` timestamp NULL default NULL,
            `date_modified` timestamp NULL default NULL,
            `ts` timestamp NULL default NULL,
            `web_address` varchar(255) default NULL,
            `arrival_times` text,
            `state` varchar(64) default NULL,
            `currency_code` varchar(3) default NULL,
            `currency_symbol` varchar(1) default NULL,
            `display_calendar` tinyint(1) default '1',
            `allow_booking` tinyint(1) default '1',
            `allow_same_day_booking` TINYINT NOT NULL DEFAULT 1,
            `limit_booking_days_advance` SMALLINT NOT NULL DEFAULT 0,
            `check_in` varchar(10) default NULL,
            `check_out` varchar(10) default NULL,
            `post_id` bigint,
            `area` varchar(255) default NULL,
            `order` int(10) unsigned NULL,
            `video_url` text default NULL,
            `virtual_tour_url` text default NULL,
            `beds_text` text default NULL,
            `property_name` TEXT,
            `property_title` TEXT,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableLangProperties,
            "`id` int(10) unsigned NOT NULL,
            `description` varchar(255) default NULL,
            `description_long` text,
            `details` text,
            `language_code` varchar(2) NOT NULL,
            PRIMARY KEY (`id`,`language_code`)"
        );

        $this->createTable($this->tableAmenities,
            "`id` int(10) NOT NULL auto_increment,
            `property_id` int(11) NOT NULL,
            `description` varchar(255) NOT NULL,
            PRIMARY KEY (`id`),
            UNIQUE KEY `property_id` (`property_id`,`description`)"
        );

        $this->createTable($this->tableLangAmenities,
            "`description` varchar(255) NOT NULL DEFAULT '',
            `description_translated` varchar(255) DEFAULT NULL,
            `language_code` varchar(2),
            `searchable` tinyint(1) NOT NULL default 0,
            PRIMARY KEY (`description`)"
        );

        $this->createTable($this->tablePictures,
            "`id` int(11) NOT NULL auto_increment,
            `property_id` int(11) NOT NULL,
            `position` smallint(6) default NULL,
            `caption` varchar(255) default NULL,
            `url` varchar(255) default NULL,
            `thumb_url` varchar(255) default NULL,      
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableMergedRates,
            "`id` int(11) NOT NULL auto_increment,
            `property_id` int(11) NOT NULL,
            `from_date` date default NULL,
            `to_date` date default NULL,
            `nightly` decimal(10,2) default NULL,
            `weekend_nightly` decimal(10,2) default NULL,
            `weekly` decimal(10,2) default NULL,
            `monthly` decimal(10,2) default NULL,
            `min_stay` int(11) NOT NULL default '1',
            `name` varchar(128) default NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableRules,
            "`id` int(11) NOT NULL auto_increment,
            `property_id` int(11) NOT NULL,
            `from_date` date default NULL,
            `to_date` date default NULL,
            `min_nights` int(11) NOT NULL default '1',
            `is_default` tinyint(1) NOT NULL default '0',
            `name` varchar(128) default NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tablePages,
            "`id` int(11) NOT NULL auto_increment,
            `property_id` int NOT NULL,
            `page_id` bigint NOT NULL,
            `parent_page_id` bigint default NULL,
            `enabled` tinyint(1) NOT NULL default '0',
            `featured` tinyint(1) NOT NULL default '0',        
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableLangPages,
            "`id` int(11) NOT NULL auto_increment,
            `property_id` int NOT NULL,
            `page_id` bigint NOT NULL,
            `source_page_id` bigint default NULL,
            `language_code` varchar(2) NOT NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tablePolicies,
            "`id` int(11) NOT NULL auto_increment,
            `cancellation_policy` longtext NULL,
            `deposit_policy` longtext NULL,
            `single_unit_helptext` longtext NULL,        
            `multi_unit_helptext` longtext NULL, 
            `language_code` varchar(2) NOT NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableTaxes,
            "`id` int(11) NOT NULL AUTO_INCREMENT,
            `property_id` int(11) NOT NULL,
            `type` varchar(32) NOT NULL,
            `title` varchar(255) NOT NULL,
            `value` double NOT NULL,
            `is_flat` tinyint(1) NOT NULL,
            `frequency` varchar(16) NOT NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableFees,
            "`id` int(11) NOT NULL AUTO_INCREMENT,
            `property_id` int(11) NOT NULL,
            `title` varchar(255) NOT NULL,
            `value` double NOT NULL,
            `tax_exempt` tinyint(1) NOT NULL,
            `is_flat` tinyint(1) NOT NULL,
            `type` varchar(32) NOT NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableDeposits,
            "`id` int(11) NOT NULL AUTO_INCREMENT,
            `property_id` int(11) NOT NULL,
            `title` varchar(255) NOT NULL,
            `value` double NOT NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableReviews,
            "`id` int(11) NOT NULL auto_increment,
            `property_id` int(11) NOT NULL,
            `date` datetime NOT NULL,
            `name` varchar(100) NOT NULL,
            `description` text NOT NULL,
            `language_code` varchar(2) NOT NULL,
            `stars` INTEGER NOT NULL DEFAULT 5,
            `title` LONGTEXT NOT NULL DEFAULT '',
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableLinkRotators,
            "`id` int(11) NOT NULL auto_increment,
            `url` varchar(255) NOT NULL DEFAULT '',
            `title` varchar(255) DEFAULT NULL,
            PRIMARY KEY (`id`)"
        );

        $this->createTable($this->tableLanguages,
            "`id` int(11) NOT NULL auto_increment,
            `code` varchar(7) NOT NULL,
            `name` varchar(128) NOT NULL,
            `enabled` BOOL NOT NULL DEFAULT 0,
            `locale` varchar(8) DEFAULT NULL,
            PRIMARY KEY (`id`)",
            array(
                "'1', 'en', 'English', '1', 'en_US'",
                "'2', 'de', 'German', '1', 'de_DE'",
                "'3', 'fr', 'French', '0', 'fr_FR'",
                "'4', 'es', 'Spanish', '0', 'es_ES'",
                "'5', 'ar', 'Arabic', '0', 'ar'",
                "'6', 'bs', 'Bosnian', '0', ''",
                "'7', 'bg', 'Bulgarian', '0', 'bg_BG'",
                "'8', 'ca', 'Catalan', '0', 'ca'",
                "'9', 'cs', 'Czech', '0', 'cs_CZ'",
                "'10', 'sla', 'Slavic', '0', ''",
                "'11', 'cy', 'Welsh', '0', 'cy'",
                "'12', 'da', 'Danish', '0', 'da_DK'",
                "'13', 'el', 'Greek', '0', 'el'",
                "'14', 'eo', 'Esperanto', '0', 'eo'",
                "'15', 'et', 'Estonian', '0', 'et'",
                "'16', 'eu', 'Basque', '0', 'eu'",
                "'17', 'fa', 'Persian', '0', 'fa_IR'",
                "'18', 'fi', 'Finnish', '0', 'fi_FI'",
                "'19', 'ga', 'Irish', '0', ''",
                "'20', 'he', 'Hebrew', '0', 'he_IL'",
                "'21', 'hi', 'Hindi', '0', ''",
                "'22', 'hr', 'Croatian', '0', 'hr'",
                "'23', 'hu', 'Hungarian', '0', 'hu_HU'",
                "'24', 'hy', 'Armenian', '0', ''",
                "'25', 'id', 'Indonesian', '0', 'id_ID'",
                "'26', 'is', 'Icelandic', '0', 'is_IS'",
                "'27', 'it', 'Italian', '0', 'it_IT'",
                "'28', 'ja', 'Japanese', '0', 'ja'",
                "'29', 'ko', 'Korean', '0', 'ko_KR'",
                "'30', 'ku', 'Kurdish', '0', 'ku'",
                "'31', 'la', 'Latin', '0', ''",
                "'32', 'lv', 'Latvian', '0', 'lv'",
                "'33', 'lt', 'Lithuanian', '0', 'lt'",
                "'34', 'mk', 'Macedonian', '0', 'mk_MK'",
                "'35', 'mt', 'Maltese', '0', ''",
                "'36', 'mo', 'Moldavian', '0', ''",
                "'37', 'mn', 'Mongolian', '0', ''",
                "'38', 'ne', 'Nepali', '0', ''",
                "'39', 'nl', 'Dutch', '0', 'nl_NL'",
                "'40', 'nb', 'Norwegian Bokm�l', '0', 'nb_NO'",
                "'41', 'pa', 'Punjabi', '0', ''",
                "'42', 'pl', 'Polish', '0', 'pl_PL'",
                "'43', 'pt-pt', 'Portuguese, Portugal', '0', 'pt_PT'",
                "'44', 'pt-br', 'Portuguese, Brazil', '0', 'pt_BR'",
                "'45', 'qu', 'Quechua', '0', ''",
                "'46', 'ro', 'Romanian', '0', 'ro_RO'",
                "'47', 'ru', 'Russian', '0', 'ru_RU'",
                "'48', 'sl', 'Slovenian', '0', 'sl_SI'",
                "'49', 'so', 'Somali', '0', ''",
                "'50', 'sq', 'Albanian', '0', ''",
                "'51', 'sr', 'Serbian', '0', 'sr_RS'",
                "'52', 'sv', 'Swedish', '0', 'sv_SE'",
                "'53', 'ta', 'Tamil', '0', ''",
                "'54', 'th', 'Thai', '0', 'th'",
                "'55', 'tr', 'Turkish', '0', 'tr'",
                "'56', 'uk', 'Ukrainian', '0', 'uk_UA'",
                "'57', 'ur', 'Urdu', '0', ''",
                "'58', 'uz', 'Uzbek', '0', 'uz_UZ'",
                "'59', 'vi', 'Vietnamese', '0', 'vi'",
                "'60', 'yi', 'Yiddish', '0', ''",
                "'61', 'zh-hans', 'Chinese (Simplified)', '0', 'zh_CN'",
                "'62', 'zu', 'Zulu', '0', ''",
                "'63', 'zh-hant', 'Chinese (Traditional)', '0', 'zh_TW'",
                "'64', 'ms', 'Malay', '0', 'ms_MY'"
            )
        );

        $this->createTable($this->tableSearchableAmenities,
            "`id` int(11) NOT NULL auto_increment,
            `description` varchar(255) NOT NULL DEFAULT '',
            PRIMARY KEY (`id`)"
        );
    }

    protected function createTable($tableName, $fieldDefinitions, $values=array()) {
        if ($this->db->get_var("SHOW TABLES LIKE '$tableName'") != $tableName) {
            $this->db->query("CREATE TABLE $tableName ($fieldDefinitions) DEFAULT CHARSET=utf8");
            if ($values) {
                foreach ($values as $value) {
                    $this->db->query("INSERT INTO $tableName VALUES ($value)");
                }
            }
        }
    }

    function drop() {
        $this->dropTable($this->tableProperties);
        $this->dropTable($this->tableLangProperties);
        $this->dropTable($this->tableAmenities);
        $this->dropTable($this->tableLangAmenities);
        $this->dropTable($this->tablePictures);
        $this->dropTable($this->tableRates);
        $this->dropTable($this->tableMergedRates);
        $this->dropTable($this->tableRules);
        $this->dropTable($this->tablePages);
        $this->dropTable($this->tableLangPages);
        $this->dropTable($this->tablePolicies);
        $this->dropTable($this->tableTaxes);
        $this->dropTable($this->tableFees);
        $this->dropTable($this->tableDeposits);
        $this->dropTable($this->tableReviews);
        $this->dropTable($this->tableLinkRotators);
        $this->dropTable($this->tableLanguages);
        $this->dropTable($this->tableSearchableAmenities);
    }

    protected function dropTable($tableName) {
        $this->db->query("DROP TABLE IF EXISTS $tableName");
    }

    function clean() {
        $this->cleanTable($this->tableProperties);
        $this->cleanTable($this->tableLangProperties);
        $this->cleanTable($this->tableAmenities);
        $this->cleanTable($this->tableLangAmenities);
        $this->cleanTable($this->tablePictures);
        $this->cleanTable($this->tableMergedRates);
        $this->cleanTable($this->tableRules);
        $this->cleanTable($this->tablePages);
        $this->cleanTable($this->tableLangPages);
        $this->cleanTable($this->tablePolicies);
        $this->cleanTable($this->tableTaxes);
        $this->cleanTable($this->tableFees);
        $this->cleanTable($this->tableDeposits);
        $this->cleanTable($this->tableReviews);
    }

    protected function cleanTable($tableName) {
        $this->db->query("DELETE FROM $tableName");
    }

}
