<?php

class p_lodgix {

    var $p_lodgix_db_version = '3.2';
    
    /**
    * @var string $url The url to this plugin
    */
    var $url = '';
    /**
    * @var string $urlpath The path to this plugin
    */
    var $urlpath = '';
    var $p_plugin_path = NULL;

    var $locale = 'en_US';
    var $sufix = 'en';

    var $page_titles = array();

    var $translator = NULL;

    public function __construct() {
        global $wpdb;
        $prefix = $wpdb->prefix;
        $this->properties_table = $prefix . LodgixConst::TABLE_PROPERTIES;
        $this->amenities_table = $prefix . LodgixConst::TABLE_AMENITIES;
        $this->merged_rates_table = $prefix . LodgixConst::TABLE_MERGED_RATES;
        $this->rules_table = $prefix . LodgixConst::TABLE_RULES;
        $this->pictures_table = $prefix . LodgixConst::TABLE_PICTURES;
        $this->pages_table = $prefix . LodgixConst::TABLE_PAGES;
        $this->lang_pages_table = $prefix . LodgixConst::TABLE_LANG_PAGES;
        $this->lang_properties_table = $prefix . LodgixConst::TABLE_LANG_PROPERTIES;
        $this->translation_table = $prefix . LodgixConst::TABLE_WPML_TRANSLATIONS;
        $this->taxes_table = $prefix . LodgixConst::TABLE_TAXES;
        $this->fees_table = $prefix . LodgixConst::TABLE_FEES;
        $this->deposits_table = $prefix . LodgixConst::TABLE_DEPOSITS;
        $this->reviews_table = $prefix . LodgixConst::TABLE_REVIEWS;
        $this->languages_table = $prefix . LodgixConst::TABLE_LANGUAGES;
        $this->link_rotators_table = $prefix . LodgixConst::TABLE_LINK_ROTATORS;
        $this->policies_table = $prefix . LodgixConst::TABLE_POLICIES;
        $this->searchable_amenities_table = $prefix . LodgixConst::TABLE_SEARCHABLE_AMENITIES;

        //"Constants" setup
        $this->url = plugins_url(basename(PLUGIN_PATH), PLUGIN_PATH);
        $this->urlpath = plugins_url('', PLUGIN_PATH);

        $this->config = new LodgixServiceConfig();

        //Admin menu
        add_action("admin_menu", array(&$this,"admin_menu_link"));

        //Actions
        add_action('wp_enqueue_scripts', array(&$this, 'load_js_and_css'));
        add_action('admin_enqueue_scripts', array(&$this, 'load_admin_js_and_css'));
        add_action("init", array(&$this,"p_lodgix_init"));
        add_action('wp_head', array(&$this,"p_lodgix_header_code"));
        add_action('wp_ajax_p_lodgix_notify', array(&$this,"p_lodgix_notify"));
        add_action('wp_ajax_nopriv_p_lodgix_notify', array(&$this,"p_lodgix_notify"));
        add_action('wp_ajax_p_lodgix_geturls', array(&$this,"p_lodgix_geturls"));
        add_action('wp_ajax_nopriv_p_lodgix_geturls', array(&$this,"p_lodgix_geturls"));
        add_action('wp_ajax_p_lodgix_check', array(&$this,"p_lodgix_check"));
        add_action('wp_ajax_nopriv_p_lodgix_check', array(&$this,"p_lodgix_check"));
        add_action('wp_ajax_p_lodgix_sort_vr', array(&$this,"p_lodgix_sort_vr"));
        add_action('wp_ajax_nopriv_p_lodgix_sort_vr', array(&$this,"p_lodgix_sort_vr"));

        add_action('wp_ajax_p_lodgix_properties_list', array(&$this,"p_lodgix_properties_list"));
        add_action('wp_ajax_p_lodgix_toggle_featured', array(&$this,"p_lodgix_toggle_featured"));
        add_action('wp_ajax_p_lodgix_toggle_select_all', array(&$this,"p_lodgix_toggle_select_all"));

        add_action('wp_ajax_p_lodgix_save_settings', array(&$this,"p_lodgix_save_settings"));
        add_action('wp_ajax_p_lodgix_clean_database', array(&$this,"p_lodgix_clean_database"));

        add_action('wp_ajax_p_lodgix_custom_search', array(&$this,"p_lodgix_custom_search"));
        add_action('wp_ajax_nopriv_p_lodgix_custom_search', array(&$this,"p_lodgix_custom_search"));

        add_action('wp_ajax_p_lodgix_custom_search_get_details', array(&$this,"p_lodgix_custom_search_get_details"));
        add_action('wp_ajax_nopriv_p_lodgix_custom_search_get_details', array(&$this,"p_lodgix_custom_search_get_details"));

        add_action("template_redirect", array(&$this,"p_lodgix_template_redirect"));

        register_activation_hook(PLUGIN_PATH, array(&$this,'p_lodgix_activate'));
        register_deactivation_hook(PLUGIN_PATH, array(&$this,'p_lodgix_deactivate'));
        add_filter( 'wp_list_pages_excludes', array(&$this,'p_lodgix_remove_pages_from_list'));

        // Menus
        add_filter('wp_get_nav_menu_items',array(&$this,'p_lodgix_nav_menus'),10,3);

        // Content
        add_filter('the_content', array(&$this,'p_lodgix_filter_content'));
        add_shortcode('lodgix_vacation_rentals', array(&$this,'p_lodgix_pcode_vacation_rentals'));
        add_shortcode('lodgix_vacation_rentals_de', array(&$this,'p_lodgix_pcode_vacation_rentals'));
        add_shortcode('lodgix_availability', array(&$this,'p_lodgix_pcode_availability'));
        add_shortcode('lodgix_availability_de', array(&$this,'p_lodgix_pcode_availability'));
        add_shortcode('lodgix_search_rentals', array(&$this,'p_lodgix_pcode_search_rentals'));
        add_shortcode('lodgix_search_rentals_de', array(&$this,'p_lodgix_pcode_search_rentals'));
        add_shortcode('lodgix_single_property', array(&$this,'p_lodgix_pcode_lodgix_single_property'));
        add_shortcode('lodgix_single_property_de', array(&$this,'p_lodgix_pcode_lodgix_single_property'));
        add_filter("gform_pre_render", array(&$this,'p_lodgix_pre_render_function'));
        add_filter("gform_admin_pre_render", array(&$this,'p_lodgix_pre_render_function'));
    }

    function load_js_and_css() {
        $this->load_js_and_css_jquery();
        $this->load_js_and_css_jquery_lodgix();
    }

    function load_js_and_css_jquery() {
        $path = $this->p_plugin_path;

        wp_enqueue_script('lodgix_jquery_latest_js', $path . 'js/jquery-1.11.3.min.js');
        wp_enqueue_script('lodgix_jquery_migrate_js', $path . 'js/jquery-migrate-1.2.1.min.js');
        wp_enqueue_script('lodgix_jquery_form_js', $path . 'js/jquery.form.min.js');
        wp_enqueue_style('lodgix_royalslider_css', $path . 'royalslider/royalslider.css');
        wp_enqueue_style('lodgix_royalslider_skin_css', $path . 'royalslider/skins/default-inverted/rs-default-inverted.css');
        wp_enqueue_script('lodgix_royalslider_js', $path . 'royalslider/jquery.royalslider.min.js');
        wp_enqueue_script('lodgix_jsrender_js', $path . 'js/jsrender.min.js');
        wp_enqueue_style('lodgix_tooltip_css', $path . 'lodgix-tooltip/lodgix-tooltip.min.css');
        wp_enqueue_script('lodgix_tooltip_js', $path . 'lodgix-tooltip/lodgix-tooltip.min.js');
        wp_enqueue_script('lodgix_jquery_confirm_js', $path . 'jquery.confirm/jquery.confirm.min.js');
    }

    function load_js_and_css_jquery_lodgix() {
        $path = $this->p_plugin_path;

        wp_enqueue_script('lodgix_jquery_no_conflict_js', $path . 'js/jquery-no-conflict.js');

        wp_enqueue_script('lodgix_jquery_js', $path . 'js/jquery_lodgix.js');
        wp_enqueue_script('lodgix_jquery_ui_js', $path . 'js/jquery-ui-lodgix.min.js');
        wp_enqueue_style('lodgix_jquery_ui_css', $path . 'css/jquery-ui-1.8.17.custom.css');

        wp_enqueue_script('lodgix_jquery_corner_js', $path . 'js/jquery.corner.js');
        wp_enqueue_script('lodgix_jquery_swf_object_js', $path . 'js/jquery.swfobject.js');
        wp_enqueue_script('lodgix_jquery_ceebox_js', $path . 'js/jquery.ceebox.js');
        wp_enqueue_style('lodgix_jquery_ceebox_css', $path . 'css/jquery.ceebox.css');

        wp_enqueue_script('lodgix_jquery_responsive_table_js', $path . 'js/jquery.lodgix-responsive-table.js');
        wp_enqueue_script('lodgix_jquery_text_expander_js', $path . 'js/jquery.lodgix-text-expander.js');
        wp_enqueue_script('lodgix_slider_js', $path . 'js/lodgix-slider.js');
        wp_enqueue_script('lodgix_map_js', $path . 'js/lodgix-map.js');

        wp_enqueue_style('lodgix_font_open_sans_css', esc_url_raw('//fonts.googleapis.com/css?family=Open+Sans:400,600,700,600italic,700italic,400italic'));
        wp_enqueue_style('lodgix_font_open_sans_condensed_css', esc_url_raw('//fonts.googleapis.com/css?family=Open+Sans+Condensed:300,300italic,700'));
        wp_enqueue_style('lodgix_common_css', $path . 'css/common.css');
        wp_enqueue_style('lodgix_inventory_common_css', $path . 'css/inventory/common.css');
        wp_enqueue_style('lodgix_inventory_grid1_css', $path . 'css/inventory/grid1.css');
        wp_enqueue_style('lodgix_inventory_rows1_css', $path . 'css/inventory/rows1.css');
        wp_enqueue_style('lodgix_inventory_rows2_css', $path . 'css/inventory/rows2.css');
        wp_enqueue_style('lodgix_property_common_css', $path . 'css/property/common.css');
        wp_enqueue_style('lodgix_widgets_featured_css', $path . 'css/widgets/featured.css');
        wp_enqueue_style('lodgix_widgets_search1_css', $path . 'css/widgets/search1.css');
        wp_enqueue_style('lodgix_widgets_search2_css', $path . 'css/widgets/search2.css');
    }

    function load_admin_js_and_css($hook) {
        if (is_admin() && $hook == 'settings_page_lodgix') {
            $path = $this->p_plugin_path;

            $this->load_js_and_css_jquery();

            wp_enqueue_style('lodgix_bootstrap_css', $path . 'bootstrap/css/bootstrap.min.css');
            wp_enqueue_script('lodgix_bootstrap_js', $path . 'bootstrap/js/bootstrap.min.js');
            wp_enqueue_script('lodgix_bootstrap_tabcollapse', $path . 'bootstrap-tabcollapse/bootstrap-tabcollapse.js');

            $this->load_js_and_css_jquery_lodgix();

            wp_enqueue_script('p_lodgix_jquery_validate_js', $path . 'js/jquery.validate.min.js');

            wp_enqueue_style('p_lodgix_ajax', $path . 'datatables/css/jquery.dataTables.min.css');
            wp_enqueue_script('p_lodgix_ajax', $path . 'datatables/js/jquery.dataTables.js');

            wp_enqueue_script('p_lodgix_script', $path . 'js/lodgix_javascript.js');

            wp_localize_script( 'p_lodgix_script', 'p_lodgix_lang', array(
                'required' => LodgixTranslate::translate('Field is required.'),
                'number' => LodgixTranslate::translate('Please enter a number.'),
                'min' => LodgixTranslate::translate('Please enter a value greater than or equal to 1.'),
            ));

            wp_localize_script('p_lodgix_script', 'p_lodgix_ajax', array(
                'ajaxURL' => admin_url('admin-ajax.php')
            ));

            wp_enqueue_script('lodgix_admin_tab_property_list_js', $path . 'js/admin-tab-property-list.js');
            wp_enqueue_script('lodgix_admin_tab_property_detail_js', $path . 'js/admin-tab-property-detail.js');
        }
    }

    function p_lodgix_set_page_titles() {
        global $wpdb;

        $this->page_titles = array();

        $active_languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
        foreach ($active_languages as $l) {
            unload_textdomain(LodgixTranslate::LOCALIZATION_DOMAIN);
            $mo =  WP_CONTENT_DIR . '/'  . "languages/" .LodgixTranslate::LOCALIZATION_DOMAIN .'-' .$l->locale.".mo";
            if (!load_textdomain(LodgixTranslate::LOCALIZATION_DOMAIN, $mo))
            {
                $mo =  trailingslashit( plugin_dir_path( PLUGIN_PATH )) . "languages/" .LodgixTranslate::LOCALIZATION_DOMAIN .'-' .$l->locale.".mo";
                load_textdomain(LodgixTranslate::LOCALIZATION_DOMAIN, $mo);
            }

            $vacation_rentals =  LodgixTranslate::translate('Vacation Rentals');

            $availability =  LodgixTranslate::translate('Availability');

            $search = LodgixTranslate::translate('Search Rentals');

            $this->page_titles[$l->code] = array(
                'vacation_rentals' => $vacation_rentals,
                'availability' => $availability,
                'search' => $search
            );
       }

       $this->p_lodgix_load_locale();
    }

    function p_lodgix_load_locale() {

        global $sitepress;

        $this->locale = get_locale();
        $this->sufix = substr($this->locale,0,2);


        $mo =  WP_CONTENT_DIR . '/'  . "languages/" .LodgixTranslate::LOCALIZATION_DOMAIN .'-' .$this->locale.".mo";


        if (!load_textdomain(LodgixTranslate::LOCALIZATION_DOMAIN, $mo))
        {
            $mo =  trailingslashit( plugin_dir_path( PLUGIN_PATH )) . "languages/" .LodgixTranslate::LOCALIZATION_DOMAIN .'-' .$this->locale.".mo";
            load_textdomain(LodgixTranslate::LOCALIZATION_DOMAIN, $mo);


        }

    }

    function p_lodgix_pre_render_function($form) {
        global $wpdb;

        //TODO: SELECT FORM ID
        //if($form["id"] != 5)
        //   return $form;

        //Creating drop down item array.
        $items = array();

        //Adding initial blank value.
        //$items[] = array("text" => "Not Selected", "value" => "0");

        //Adding post titles to the items array
        $properties = $wpdb->get_results('SELECT * FROM ' . $this->properties_table . ' ORDER BY `order`');
        if ($properties)
        {
            foreach($properties as $property)
            {
              $items[] = array("value" => $property->id, "text" => $property->description);
            }
        }

        //Adding items to field id 8. Replace 8 with your actual field id. You can get the field id by looking at the input name in the markup.
        foreach($form["fields"] as &$field)
        if(trim($field["inputName"]) == 'lodgix_property_id'){
            $field["choices"] = $items;
        }

        return $form;
    }


    function p_lodgix_pcode_vacation_rentals($atts) {
        return $this->get_vacation_rentals_content();
    }

    function p_lodgix_pcode_availability($atts) {
        return $this->get_availability_page_content();
    }

    function p_lodgix_pcode_search_rentals($atts) {
        return $this->get_search_rentals_page_content();
    }

    function p_lodgix_pcode_lodgix_single_property($atts) {
        $p_lodgix_property_id = $atts[0];
        return $this->get_single_page_content($p_lodgix_property_id);
    }

    function p_lodgix_pcode_lodgix_single_property_de($atts) {
        $p_lodgix_property_id = $atts[0];
        return $this->get_single_page_content($p_lodgix_property_id);
    }

    function p_lodgix_filter_content($content)
    {
        if (get_option(LodgixConst::OPTION_DB_VERSION))
        {
            $old_db_version = ((float)get_option(LodgixConst::OPTION_DB_VERSION));

            if ($old_db_version < ((float)$this->p_lodgix_db_version))
            {
                $this->update_db($old_db_version);
            }

        }
        update_option(LodgixConst::OPTION_DB_VERSION, $this->p_lodgix_db_version);

        if (strrpos($content,'[lodgix vacation_rentals]') > 0)
            $content = str_replace('[lodgix vacation_rentals]',$this->get_vacation_rentals_content(),$content);
        if (strrpos($content,'[lodgix availability]') > 0)
            $content = str_replace('[lodgix availability]',$this->get_availability_page_content(),$content);
        if (strrpos($content,'[lodgix search_rentals]') > 0)
            $content = str_replace('[lodgix search_rentals]',$this->get_search_rentals_page_content(),$content);

        if (strrpos($content,'[lodgix area de ') !==  false)
            $content = str_replace($content,$this->get_area_page_content($content),$content);
        else if (strrpos($content,'[lodgix area ') !==  false)
            $content = str_replace($content,$this->get_area_page_content($content),$content);

        return $content;
    }

    function cmp_menu_order($a,$b)
    {
        if ($a->menu_order == $b->menu_order)
            return 0;
        else if ($a->menu_order > $b->menu_order)
            return 1;
        else if ($a->menu_order < $b->menu_order)
            return -1;
    }

    function p_lodgix_nav_menus($items, $menu, $args)
    {
      global $wpdb;

      if (!strrpos($_SERVER['SCRIPT_NAME'],'nav-menus'))
      {

        $pos1 = $this->config->get('p_lodgix_vacation_rentals_page_pos');
        $pos2 = $this->config->get('p_lodgix_availability_page_pos');

        if ($pos1 != '-1')
        {
            foreach($items as $item)
            {
                if ($item->menu_order >= $pos1)
                {
                    $item->menu_order++;
                }
            }
        }
        if ($pos2 != '-1')
        {
            foreach($items as $item)
            {
                if ($item->menu_order >= $pos2)
                {
                    $item->menu_order++;
                }
            }
        }

        if (strpos($this->locale, 'en') !== false)
        {
            if ($pos1 != '-1')
            {
                $post = get_post($this->config->get('p_lodgix_vacation_rentals_page_en'));
                $item = wp_setup_nav_menu_item($post,'post_type');
                $item->menu_order = $pos1;
                $items[] = $item;
            }
            if ($pos2 != '-1')
            {
                $post = get_post($this->config->get('p_lodgix_availability_page_en'));
                $item = wp_setup_nav_menu_item($post);
                $item->menu_order = $pos2;
                $items[] = $item;
            }
        }
        else
        {

            if ($pos1 != '-1')
            {
                $post_id = $wpdb->get_var("SELECT page_id FROM " . $this->lang_pages_table . " WHERE property_id=-1 AND language_code='" . $this->sufix. "'");
                $post = get_post($post_id);
                $item = wp_setup_nav_menu_item($post);
                $item->menu_order = $pos1;
                $items[] = $item;
            }
            if ($pos2 != '-1')
            {
                $post_id = $wpdb->get_var("SELECT page_id FROM " . $this->lang_pages_table . " WHERE property_id=-2 AND language_code='" . $this->sufix. "'");
                $post = get_post($post_id);
                $item = wp_setup_nav_menu_item($post);
                $item->menu_order = $pos2;
                $items[] = $item;
            }
        }

        usort( $items, array(&$this,'cmp_menu_order'));
       }

       return $items;

    }

    function p_lodgix_remove_pages_from_list($excludes) {
        global $wpdb;
        $posts = $wpdb->get_results('SELECT * FROM ' . $this->pages_table);
        foreach($posts as $post)
        {
            if (!$post->enabled)
            {
                array_push($excludes,$post->page_id);
            }
        }
        return $excludes;
    }

    function p_lodgix_toggle_select_all() {
        global $wpdb;
        if ($_POST['checked'] == 'true') $checked = 1; else $checked = 0;

        $this->config->set('p_lodgix_featured_select_all', $checked);
        $this->config->save();

        die(json_encode(array('result' => 'OK')));

    }

    function p_lodgix_toggle_featured() {
        global $wpdb;
        if ($_POST['checked'] == 'true') $checked = 1; else $checked = 0;
        $id = @esc_sql($_POST['id']);

        $sql = 'UPDATE ' . $this->pages_table . ' SET featured=' . $checked . ' WHERE property_id = ' . $id;
        $wpdb->query($sql);
        die(json_encode(array('result' => 'OK')));

    }

    function p_lodgix_properties_list() {
        global $wpdb;

        $properties = $wpdb->get_results('SELECT ' . $this->properties_table . '.id, `order`, property_id, description,enabled,featured FROM ' . $this->properties_table . ' LEFT JOIN ' . $this->pages_table . ' ON ' . $this->properties_table . '.id = ' . $this->pages_table . '.property_id ORDER BY ' . $this->properties_table . '.`order`');

        $items = array();
        foreach($properties as $property)
        {

            if ($property->featured) $checked = 'CHECKED'; else $checked = '';

            if ($this->config->get('p_lodgix_featured_select_all')) $disabled = 'DISABLED'; else $disabled = '';

            $featured = '
                <input type="checkbox" id="lodgix_featured_property_' . $property->property_id . '"
                    class="lodgix_featured_property" ' . $checked . ' ' . $disabled . ' 
                    onclick="javascript:toggle_lodgix_featured_property(' . $property->property_id . ');"
                    
                >
            ';
            $items[] = array(
                "order" => $property->order + 1,
                "id" => $property->property_id,
                "name" => $property->description,
                "featured" => $featured
            );
        }


        $output = array(
            'sColumns' => 'ID, Name, Featured',
            'sEcho' => intval($_GET['sEcho']),
            'iTotalRecords' => count($properties),
            'iTotalDisplayRecords' => 50,
            'aaData' => $items
        );

        die(json_encode($output));

    }

    function p_lodgix_sort_vr() {
        $this->p_lodgix_load_locale();
        $sort = isset($_POST['lodgix-property-list-sort']) ? @esc_sql($_POST['lodgix-property-list-sort']) : '';
        $area = isset($_POST['lodgix-custom-search-area']) ? @esc_sql($_POST['lodgix-custom-search-area']) : '';
        $bedrooms = isset($_POST['lodgix-custom-search-bedrooms']) ? @esc_sql($_POST['lodgix-custom-search-bedrooms']) : null;
        $priceFrom = isset($_POST['lodgix-custom-search-daily-price-from']) ? @esc_sql($_POST['lodgix-custom-search-daily-price-from']) : null;
        $priceTo = isset($_POST['lodgix-custom-search-daily-price-to']) ? @esc_sql($_POST['lodgix-custom-search-daily-price-to']) : null;
        $id = isset($_POST['lodgix-custom-search-id']) ? @esc_sql($_POST['lodgix-custom-search-id']) : '';
        $arrival = isset($_POST['lodgix-custom-search-arrival']) ? @esc_sql($_POST['lodgix-custom-search-arrival']) : '';
        $nights = isset($_POST['lodgix-custom-search-nights']) ? @esc_sql($_POST['lodgix-custom-search-nights']) : '';
        $amenities = array();
        if (isset($_POST['lodgix-custom-search-amenity']) && is_array($_POST['lodgix-custom-search-amenity'])) {
            foreach ($_POST['lodgix-custom-search-amenity'] as $a) {
                array_push($amenities, @esc_sql($a));
            }
        }
        $content = $this->get_vacation_rentals_html($sort, $area, $bedrooms, $id, $arrival, $nights, $amenities, $priceFrom, $priceTo);
        die($content);
    }


    function p_lodgix_init() {
        $this->p_plugin_path = plugin_dir_url(plugin_basename(PLUGIN_PATH));
        $this->p_lodgix_load_locale();

    }

    function p_is_lodgix_page($id)
    {
        global $wpdb;

        $active_languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');

        foreach ($active_languages as $l) {
            switch ($id)
            {
                case $this->config->get('p_lodgix_vacation_rentals_page_' . $l->code):  return true;
                                                                            break;

                case $this->config->get('p_lodgix_vacation_rentals_page_' . $l->code):   return true;
                                                                                break;

                case $this->config->get('p_lodgix_availability_page_' . $l->code):  return true;
                                                                                break;
            }
        }

        $post_id = $wpdb->get_var("SELECT page_id FROM " . $this->pages_table . " WHERE page_id=" . $id);
        if ($post_id == $id)
          return true;

        $post_id = $wpdb->get_var("SELECT page_id FROM " . $this->lang_pages_table . " WHERE page_id=" . $id);
        if ($post_id == $id)
          return true;

        foreach ($active_languages as $l) {
            $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            if (is_array($areas_pages)) {
                foreach($areas_pages as $key => $page)
                {
                    if ($page->page_id == $id)
                      return true;
                }
            }
        }

        return false;
    }

    function p_lodgix_template_redirect()
    {
        global $wp_query;

        if ($wp_query->post->ID && $this->p_is_lodgix_page($wp_query->post->ID))
        {

            if ($this->config->get('p_lodgix_page_template') && $this->config->get('p_lodgix_page_template') != '')
            {
                if ($this->config->get('p_lodgix_page_template') && $this->config->get('p_lodgix_page_template') == 'CUSTOM')
                {
                    $template = WP_CONTENT_DIR . '/' . $this->config->get('p_lodgix_custom_page_template');
                }
                else {
                    $template = TEMPLATEPATH . '/' . $this->config->get('p_lodgix_page_template');
                }

                if (file_exists($template)) {
                    include($template);
                    die();
                }
            }
            else
            {
                $current_theme = get_current_theme();
                if ($this->config->get('p_lodgix_thesis_compatibility'))
                {
                    include('thesis_no_sidebars.php');
                    die();
                }
                else if ($this->config->get('p_lodgix_thesis_2_compatibility'))
                {

                }
                else if ($current_theme  == "FlexSqueeze")
                {

                }
                else if ($current_theme  == "pureVISION")
                {
                    include('purevision_page_template.php');
                    die();
                }
                else
                {
                    include('lodgix_page_template.php');
                    die();
                }
            }
        }
    }

    function p_lodgix_header_code() {
        global $post;
        global $wpdb;

        if (!$post) {
            return;
        }

        $post_id = $post->ID;
        echo "\n".'<!-- Start Lodgix -->'."\n";
        if (!$this->config->get('p_lodgix_thesis_compatibility') && !$this->config->get('p_lodgix_thesis_2_compatibility')) {
            $properties = $wpdb->get_results('SELECT description,description_long,city,area FROM ' . $this->properties_table . ' WHERE post_id=' . $post_id);
            if ($properties) {
                $property = $properties[0];
                echo '<meta name="description" content="' . trim(wptexturize($this->truncate_text($property->description_long,150))) . '" />';
                $keywords = $property->description . ', vacation rental, vacation home, vacation, homes, rentals, cottages, condos, holiday';
                if ($property->city != "") {
                    $keywords .= ', ' . $property->city;
                }
                echo '<meta name="keywords" content="' . trim(wptexturize($keywords)) . '" />';
            }
        }

        $css_path = WP_CONTENT_DIR;
        if (file_exists($css_path  . '/lodgix-custom.css')) {
            echo '<link type="text/css" rel="stylesheet" href="' . WP_CONTENT_URL  . '/lodgix-custom.css" />' . "\n";
        }
        ?><script>
            jQueryLodgix(document).ready(function() {
                if (location.hash != '') {
                    location.hash = location.hash;
                }
                jQueryLodgix(".ceebox").ceebox({videoGallery:'false'});
            });
        </script>
        <?php
        echo '<!-- End Of Lodgix -->'."\n";
    }

    function p_lodgix_deactivate() {
    }

    function p_lodgix_activate() {
    }

      /**
      * @desc Adds the options subpanel
      */
      function admin_menu_link() {
          add_options_page('Lodgix Settings', 'Lodgix Settings', 10, basename(PLUGIN_PATH), array(&$this, 'admin_options_page'));
          add_filter( 'plugin_action_links_' . plugin_basename(PLUGIN_PATH), array(&$this, 'filter_plugin_actions'), 10, 2 );
      }

      /**
      * @desc Adds the Settings link to the plugin activate/deactivate page
      */
      function filter_plugin_actions($links, $file) {
         $settings_link = '<a href="options-general.php?page=' . basename(PLUGIN_PATH) . '">' . LodgixTranslate::translate('Settings') . '</a>';
         array_unshift( $links, $settings_link ); // before other links

         return $links;
      }

    /*
        Builds areas page
    */
    function build_areas_pages()
    {
        global $sitepress, $wpdb;
        $areas = $wpdb->get_results('SELECT DISTINCT area FROM ' . $this->properties_table . ' WHERE area is not NULL');
        $active_languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
        $all_languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table);

        foreach ($all_languages as $l) {
            $translated_areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            if (is_array($translated_areas_pages) && count($translated_areas_pages) > 0) {
                foreach($translated_areas_pages as $key => $page)
                {
                    if (!get_post($page->page_id)) unset($translated_areas_pages[$key]);

                }
                $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize($translated_areas_pages));
            }
        }

        $this->config->save();

        foreach ($all_languages as $l) {
            $translated_areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            if (is_array($translated_areas_pages) && count($translated_areas_pages) > 0) {
                foreach($translated_areas_pages as $key => $page)
                {
                    $found = false;
                    if (count($areas) > 0)  {
                        foreach($areas as $area)
                        {
                            if ($page->area == $area->area)
                            {
                                $found = true;
                                break;
                            }
                        }
                    }

                    if (!$found)
                    {
                        wp_delete_post($translated_areas_pages[$key]->page_id);
                        unset($translated_areas_pages[$key]);
                    }
                }
                $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize($translated_areas_pages));
            }
        }
        $this->config->save();

        foreach ($active_languages as $l)
        {
            $translated_areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            if (count($areas) > 0)
            {
                foreach($areas as $area)
                {
                    $found = false;
                    if (is_array($translated_areas_pages) && count($translated_areas_pages) > 0) {
                        foreach($translated_areas_pages as $page)
                        {
                            if ($page->area == $area->area)
                            {
                                $found = true;
                                break;
                            }
                        }
                    }

                    if (!$found)
                    {
                        $obj = (object)array(
                            'area' => $area->area,
                            'page_id' => NULL
                        );
                        $translated_areas_pages[] = $obj;
                    }
                }
            }

            $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize($translated_areas_pages));
        }
        $this->config->save();

        foreach ($active_languages as $l)
        {
            $translated_areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));

            if (is_array($translated_areas_pages) && count($translated_areas_pages) > 0) {
                $counter = 0;
                foreach($translated_areas_pages as $key => $page)
                {
                    $post = array();
                    $post['post_title'] = $page->area;
                    $post['post_status'] = 'publish';
                    $post['post_author'] = 1;
                    $post['post_type'] = "page";
                    if ($page->page_id == NULL)
                    {
                        $post_id = wp_insert_post($post);
                        if ($post_id != 0)
                        {
                            $translated_areas_pages[$key]->page_id = (int)$post_id;
                        }
                    }

                    $counter++;
                }
                $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize($translated_areas_pages));
            }
        }
        $this->config->save();

        $this->link_translated_pages();

        foreach ($active_languages as $l)
        {
            $translated_areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));

            if (is_array($translated_areas_pages) && count($translated_areas_pages) > 0) {
                foreach($translated_areas_pages as $key => $page)
                {
                    if ($translated_areas_pages[$key]->page_id) {
                        $wpost = array();
                        $wpost['ID'] = $translated_areas_pages[$key]->page_id;
                        $wpost['post_content'] = '[lodgix area ' . $translated_areas_pages[$key]->page_id . ']';
                        wp_update_post($wpost);
                    }
                }
            }

        }

    }

    function get_property_ids_with_amenities($amenities) {
        global $wpdb;

        if (!($amenities && is_array($amenities))) {
            return '';
        }

        $len = count($amenities);
        for ($i = 0; $i < $len; $i++) {
            $amenities[$i] = @esc_sql($amenities[$i]);
        }
        $propertyIds = array();
        $properties = $wpdb->get_results('SELECT property_id, count(property_id) AS amenities FROM ' . $wpdb->prefix . "lodgix_amenities WHERE description IN ('" . join("','", $amenities) . "') GROUP BY property_id HAVING amenities=" . $len . "");
        foreach ($properties as $property) {
            array_push($propertyIds, $property->property_id);
        }
        return $this->properties_table . '.id IN (' . join(',', $propertyIds) . ') AND ';
    }

    function get_property_book_link($property_id, $book_dates) {
        $owner_id = $this->config->get('p_lodgix_owner_id');
        if ($owner_id == 2) {
            $owner_id = 'rosewoodpointe';
        } else if ($owner_id == 13) {
            $owner_id = 'demo_booking_calendar';
        } else {
            $matches = Array();
            preg_match('/([0-9])+/i', $owner_id, $matches);
            $owner_id = $matches[0];
        }
        return 'https://www.lodgix.com/' . $owner_id . '/?selected_reservations='
            . $property_id . ',' . $book_dates
            . '&adult=1&children=0&external=1';
    }

    function get_vacation_rentals_html($sort='', $area='', $bedrooms=NULL, $id='', $arrival='', $nights='', $amenities=NULL, $priceFrom=0, $priceTo=0) {
        global $wpdb;

        $content = '';

        $sort_sql = '';
        $direction = '';
        if ($sort) {
            $sort_sql = $wpdb->_real_escape($sort);
            if ($sort == 'pets') {
                $direction = ' DESC';
            }
        }

        $filter = '';
        if (is_numeric($id)) {
            $filter .= " (id='" . $id . "' OR description LIKE '%" . $id . "%') AND ";
        } else {
            if ($area != '' && $area != 'ALL_AREAS') {
                $filter .= " area='" . str_replace('\\\\', '', $wpdb->_real_escape($area)) . "' AND ";
            }
            if ($id != '') {
                $filter .= " UPPER(description) LIKE '%" . $wpdb->_real_escape(strtoupper($id)) . "%' AND ";
            }
            if ($bedrooms != NULL && $bedrooms != 'ANY') {
                $filter .= " bedrooms >= " . $wpdb->_real_escape($bedrooms) . " AND ";
            }
            $priceFrom = (int)$priceFrom;
            if ($priceFrom > 0) {
                $filter .= " min_daily_rate>=" . $priceFrom . " AND ";
            }
            $priceTo = (int)$priceTo;
            if ($priceTo > 0 && $priceTo >= $priceFrom) {
                $filter .= " min_daily_rate<=" . $priceTo . " AND ";
            }
        }

        $available = 'ALL';
        $available_after_rules = '';
        if (strtotime($arrival) !== false && is_numeric($nights)) {
            $differentiate = true;
            $departure = date('Y-m-d', strtotime($arrival . ' + ' . $nights . ' days'));
            $fetch_url =
                'http://www.lodgix.com/system/api-lite/xml?Action=GetAvailableProperties&PropertyOwnerID='
                . $this->config->get('p_lodgix_owner_id')
                . '&FromDate=' . $arrival
                . '&ToDate=' . $departure
                . '&Version=' . $this->p_lodgix_db_version;

            $r = new LogidxHTTPRequest($fetch_url);
            $xml = $r->DownloadToString();
            if ($xml) {
                $x = simplexml_load_string($xml);
                $available = strval($x->Results->AvailableProperties);
                $available_after_rules = explode(',', strval($x->Results->AvailablePropertiesAfterRules));
            }
        } else {
            $differentiate = false;
            $departure = '';
        }
        if (!$available || $available == 'null') {
            $filter .= " 1=0 AND ";
        } else if ($available != 'ALL') {
            $filter .= " id IN (" . $available . ") AND ";
        }

        $filter .= $this->get_property_ids_with_amenities($amenities);

        if ($this->config->get('p_lodgix_vacation_rentals_page_design') == 1) {
            $content .= '<div id="lodgix_vc_content_grid" class="ldgxInventoryGrid">';
            if (!$sort_sql) {
                $sort_sql = "IF (area = '' OR area IS NULL,1,0) , `area`, description";
            }
        } elseif ($this->config->get('p_lodgix_vacation_rentals_page_design') == 2) {
            $content .= '<div id="lodgix_vc_content" class="ldgxInventoryList ldgxInventoryTheme2">';
        } else {
            $content .= '<div id="lodgix_vc_content" class="ldgxInventoryList ldgxInventoryTheme1">';
        }

        $content .= $this->get_sort_form_html($area);

        if ($bedrooms != NULL && $bedrooms != 'ANY') {
            if ($sort_sql) {
                $sort_sql .= ', bedrooms';
            } else {
                $sort_sql = 'bedrooms';
            }
        }

        if (!$sort_sql) {
            $sort_sql = '`order`';
        }

        $properties = $wpdb->get_results("SELECT * FROM $this->properties_table WHERE $filter 1=1 ORDER BY $sort_sql $direction");

        $counter = 0;

        if ($properties) {
            foreach ($properties as $property) {


                if ($counter == 0) {
                    $old_area = $property->area;
                }

                if (is_array($available_after_rules)) {
                    foreach ($available_after_rules as $pk) {
                        if ($pk == $property->id) {
                            $property->bookdates = $arrival . ',' . $departure;
                            $property->booklink = $this->get_property_book_link($property->id, $property->bookdates);
                            $property->really_available = true;
                            break;
                        }
                    }
                }

                if (strpos($this->locale, 'en') !== false) {
                    $permalink = get_permalink($property->post_id);
                } else {
                    $sql = "SELECT * FROM " . $this->lang_properties_table . " WHERE language_code='" . $this->sufix . "' AND id=" . $property->id;
                    $translated_details = $wpdb->get_results($sql);
                    $translated_details = $translated_details[0];
                    $property->description = $translated_details->description;
                    $property->description_long = $translated_details->description_long;
                    $property->details = $translated_details->details;
                    $post_id = $wpdb->get_var("select page_id from " . $this->lang_pages_table . " WHERE property_id=" . $property->id . " AND language_code='" . $this->sufix . "';");
                    $permalink = get_permalink($post_id);
                }

                if ($property->main_image) {

                    if ($differentiate && $property->really_available) {
                        $permalink = add_query_arg(array('bookdates' => $property->bookdates) , $permalink);
                        $permalink = esc_url($permalink);
                    }

                    $display_high_rate = $this->config->get('p_lodgix_display_search_table_high_rate');
                    $display_low_rate = !$display_high_rate;

                    $lpl = new LodgixPropertyList(
                        $property,
                        $this->config->get('p_lodgix_display_search_daily_rates'),
                        $this->config->get('p_lodgix_display_search_weekly_rates'),
                        $this->config->get('p_lodgix_display_search_monthly_rates'),
                        $permalink,
                        $display_low_rate,
                        $display_high_rate,
                        $this->config->get('p_lodgix_display_search_bedrooms'),
                        $this->config->get('p_lodgix_display_search_areas')
                    );

                    if ($this->config->get('p_lodgix_vacation_rentals_page_design') == 1) {

                        if (!$sort && $old_area != '') {
                            if (($counter == 0) || ($old_area != $property->area)) {
                                if ($property->area) {
                                    $content .= "<h2>$property->area</h2>";
                                } else {
                                    $content .= "<h2>Other Areas</h2>";
                                }
                                $counter = 0;
                            }
                        }
                        $old_area = $property->area;

                        $nofloat = false;
                        $is_new_row = ($counter % 3 == 0);

                        $content .= $lpl->gridCell(
                            $nofloat,
                            $is_new_row
                        );

                    } else {

                        if ($this->config->get('p_lodgix_contact_url_' . $this->sufix) != "") {
                            $mail_url = $this->config->get('p_lodgix_contact_url_' . $this->sufix);
                            if (strpos($mail_url, '__PROPERTY__') != false) {
                                $mail_url = str_replace('__PROPERTY__', $property->description, $mail_url);
                            }
                            if (strpos($mail_url, '__PROPERTYID__') != false) {
                                $mail_url = str_replace('__PROPERTYID__', $property->id, $mail_url);
                            }
                        } else {
                            $mail_url = '';
                        }

                        if ($differentiate && !$property->really_available) {
                            $warning =
                                '<div style="margin:10px"><span class="lodgix-icon lodgix-icon-alert" style="float:left;margin-right:.3em"></span><strong>'
                                . LodgixTranslate::translate('Rules may exist that prevent this booking from proceeding. Please check availability.',
                                    LodgixTranslate::LOCALIZATION_DOMAIN)
                                . '</strong></div>';
                        } else {
                            $warning = '';
                        }

                        $full_size_thumbnails = $this->config->get('p_lodgix_full_size_thumbnails');
                        $small_thumbnails = !$full_size_thumbnails;

                        $content .= $lpl->row(
                            $small_thumbnails,
                            $full_size_thumbnails,
                            $this->config->get('p_lodgix_display_search_learn_more_book_now_button'),
                            $warning,
                            $this->config->get('p_lodgix_icon_set'),
                            $this->config->get('p_lodgix_display_search_table_icons'),
                            $this->config->get('p_lodgix_display_search_bathrooms'),
                            $this->config->get('p_lodgix_display_search_guests'),
                            $this->config->get('p_lodgix_display_search_type'),
                            $this->config->get('p_lodgix_display_search_pets'),
                            $this->config->get('p_lodgix_display_availability_icon'),
                            $this->config->get('p_lodgix_display_icons'),
                            $mail_url,
                            $differentiate,
                            $property->booklink
                        );

                    }
                    $counter += 1;
                }

            }
            $content .= '<script type="text/javascript">jQueryLodgix(".ldgxListingFeats").LodgixResponsiveTable()</script>';
            if ($this->config->get('p_lodgix_display_search_text_expander')) {
                $content .= '<script type="text/javascript">jQueryLodgix(".ldgxListingDesc").LodgixTextExpander()</script>';
            }
        } else {
            $content .= '<p>Your search did not return any results. Please amend your search criteria and try again.</p>';
        }

        $content .= '</div>';

        $link = '<a href="http://www.lodgix.com">Vacation Rental Software</a>';

        $sql = 'SELECT url,title FROM `' . $this->link_rotators_table . '` ORDER BY RAND() LIMIT 1';
        $rotators = $wpdb->get_results($sql);

        if ($rotators) {
            foreach ($rotators as $rotator)
                $link = '<a target="_blank" href="' . $rotator->url . '">' . $rotator->title . '</a>';
        }

        $content .= '<div class="ldgxPowered">' . $link . ' by Lodgix.com</div>';
        return $content;
    }

    function get_sort_form_html($searchArea='') {
        $sort = isset($_POST['lodgix-property-list-sort']) ? htmlspecialchars($_POST['lodgix-property-list-sort']) : '';
        $area = isset($_POST['lodgix-custom-search-area']) ? htmlspecialchars($_POST['lodgix-custom-search-area']) : $searchArea;
        $bedrooms = isset($_POST['lodgix-custom-search-bedrooms']) ? htmlspecialchars($_POST['lodgix-custom-search-bedrooms']) : '';
        $priceFrom = isset($_POST['lodgix-custom-search-daily-price-from']) ? htmlspecialchars($_POST['lodgix-custom-search-daily-price-from']) : '';
        $priceTo = isset($_POST['lodgix-custom-search-daily-price-to']) ? htmlspecialchars($_POST['lodgix-custom-search-daily-price-to']) : '';
        $id = isset($_POST['lodgix-custom-search-id']) ? htmlspecialchars($_POST['lodgix-custom-search-id']) : '';
        $arrival = isset($_POST['lodgix-custom-search-arrival']) ? htmlspecialchars($_POST['lodgix-custom-search-arrival']) : '';
        $nights = isset($_POST['lodgix-custom-search-nights']) ? htmlspecialchars($_POST['lodgix-custom-search-nights']) : '';
        $content = '
            <div id="lodgix_sort_div" class="ldgxInventorySort">
                <form method="post" action="' . get_bloginfo('wpurl') . '/wp-admin/admin-ajax.php">
                    <strong>' . LodgixTranslate::translate('Sort Results by') . ':</strong>
                    <input type="hidden" name="action" value="p_lodgix_sort_vr">
                    <input type="hidden" name="lodgix-custom-search-lang" value="' . $this->sufix . '">
                    <input type="hidden" name="lodgix-custom-search-area" value="' . $area . '">
                    <input type="hidden" name="lodgix-custom-search-bedrooms" value="' . $bedrooms . '">
                    <input type="hidden" name="lodgix-custom-search-daily-price-from" value="' . $priceFrom . '">
                    <input type="hidden" name="lodgix-custom-search-daily-price-to" value="' . $priceTo . '">
                    <input type="hidden" name="lodgix-custom-search-id" value="' . $id . '">
                    <input type="hidden" name="lodgix-custom-search-arrival" value="' . $arrival . '">
                    <input type="hidden" name="lodgix-custom-search-nights" value="' . $nights . '">
        ';
        if (isset($_POST['lodgix-custom-search-amenity']) && is_array($_POST['lodgix-custom-search-amenity'])) {
            foreach ($_POST['lodgix-custom-search-amenity'] as $a) {
                $content .= '<input type="hidden" name="lodgix-custom-search-amenity[]" value="' . htmlspecialchars($a) . '">';
            }
        }
        $content .= '
                    <select name="lodgix-property-list-sort" onchange="jQLodgix(this.form).ajaxSubmit({target:\'.ldgxInventoryContainer\'})">
                        <option value=""' . ($sort == '' ? ' selected' : '') . '>' . LodgixTranslate::translate('None') . '</option>
                        <option value="bedrooms"' . ($sort == 'bedrooms' ? ' selected' : '') . '>' . LodgixTranslate::translate('Bedrooms') . '</option>
                        <option value="bathrooms"' . ($sort == 'bathrooms' ? ' selected' : '') . '>' . LodgixTranslate::translate('Bathrooms') . '</option>
                        <option value="proptype"' . ($sort == 'proptype' ? ' selected' : '') . '>' . LodgixTranslate::translate('Rental Type') . '</option>
                        <option value="min_daily_rate"' . ($sort == 'min_daily_rate' ? ' selected' : '') . '>' . LodgixTranslate::translate('Daily Rate') . '</option>
                        <option value="min_weekly_rate"' . ($sort == 'min_weekly_rate' ? ' selected' : '') . '>' . LodgixTranslate::translate('Weekly Rate') . '</option>
                        <option value="min_monthly_rate"' . ($sort == 'min_monthly_rate' ? ' selected' : '') . '>' . LodgixTranslate::translate('Monthly Rate') . '</option>
                    </select>
                </form>
            </div>
        ';
        return $content;
    }

    function get_area_page_content($code) {
        $content = '';
        preg_match_all('/([\d]+)/', $code, $match);
        $id = (int)$match[0][0];
        if (is_numeric($id)) {
            $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $this->sufix));
            foreach($areas_pages as $page) {
                if ($page->page_id && ($page->page_id == $id)) {
                    $content .= '<div class="ldgxInventoryContainer">';
                    $content .= $this->get_vacation_rentals_html('', $page->area);
                    $content .= '</div>';
                    break;
                }
            }
        }
        return $content;
    }

    /*
     * Get search rentals page content
     */
    function get_search_rentals_page_content() {
        $sort = @esc_sql($_POST['lodgix-property-list-sort']);
        $area = @esc_sql($_POST['lodgix-custom-search-area']);
        $bedrooms = @esc_sql($_POST['lodgix-custom-search-bedrooms']);
        $priceFrom = @esc_sql($_POST['lodgix-custom-search-daily-price-from']);
        $priceTo = @esc_sql($_POST['lodgix-custom-search-daily-price-to']);
        $id = @esc_sql($_POST['lodgix-custom-search-id']);
        $arrival = @esc_sql($_POST['lodgix-custom-search-arrival']);
        $nights = @esc_sql($_POST['lodgix-custom-search-nights']);
        $amenities = $_POST['lodgix-custom-search-amenity'];
        $content = '<div class="ldgxInventoryContainer">';
        $content .= $this->get_vacation_rentals_html($sort, $area, $bedrooms, $id, $arrival, $nights, $amenities, $priceFrom, $priceTo);
        $content .= '</div>';
        return $content;
    }

    function get_single_page_content($id) {
        global $wpdb;
        $html = '';
        $properties = $wpdb->get_results("SELECT * FROM $this->properties_table WHERE id=$id");
        if ($properties) {
            $property = $properties[0];

            $book_dates = @esc_sql($_GET['bookdates']);
            if ($book_dates) {
                $property->booklink = $this->get_property_book_link($property->id, $book_dates);
                $property->really_available = true;
            } else {
                $property->really_available = false;
            }

            if (strpos($this->locale, 'en') !== false) {
                $permalink = get_permalink($property->post_id);
            } else {
                $translated_details = $wpdb->get_results("SELECT * FROM $this->lang_properties_table WHERE id=$property->id AND language_code='$this->sufix'");
                $translated_details = $translated_details[0];
                $property->description = $translated_details->description;
                $property->description_long = $translated_details->description_long;
                $property->details = $translated_details->details;
                $post_id = $wpdb->get_var("select page_id from $this->lang_pages_table WHERE property_id=$property->id AND language_code='$this->sufix'");
                $permalink = get_permalink($post_id);
            }

            $contactUrlOption = $this->config->get('p_lodgix_contact_url_' . $this->sufix);
            $emailUrl = $contactUrlOption ? $contactUrlOption : '';

            $mapZoomLevel = $this->config->get('p_lodgix_gmap_zoom_level');
            $mapZoom = $mapZoomLevel == 0 ? 13 : $mapZoomLevel;

            $mapApiKey = $this->config->get('p_lodgix_gmap_api_key');

            $lpd = new LodgixPropertyDetail(
                $property,
                $this->config->get('p_lodgix_date_format'),
                $mapApiKey,
                $this->config->get('p_lodgix_display_daily_rates'),
                $this->config->get('p_lodgix_display_weekly_rates'),
                $this->config->get('p_lodgix_display_monthly_rates'),
                $this->config->get('p_lodgix_rates_display') == 0,
                $this->config->get('p_lodgix_rates_display') == 1,
                $permalink,
                $emailUrl,
                $this->config->get('p_lodgix_icon_set'),
                $this->config->get('p_lodgix_display_property_book_now_always'),
                $this->config->get('p_lodgix_display_beds'),
                $this->config->get('p_lodgix_image_size'),
                $this->config->get('p_lodgix_display_single_instructions'),
                $mapZoom,
                $this->sufix,
                false
            );
            if ($this->config->get('p_lodgix_single_page_design') == 1) {
                $html = $lpd->tabs(
                    $this->config->get('p_lodgix_single_page_tab_details_is_visible') ? $this->config->get('p_lodgix_single_page_tab_details') : '',
                    $this->config->get('p_lodgix_single_page_tab_calendar_is_visible') ? $this->config->get('p_lodgix_single_page_tab_calendar') : '',
                    $this->config->get('p_lodgix_single_page_tab_location_is_visible') ? $this->config->get('p_lodgix_single_page_tab_location') : '',
                    $this->config->get('p_lodgix_single_page_tab_amenities_is_visible') ? $this->config->get('p_lodgix_single_page_tab_amenities') : '',
                    $this->config->get('p_lodgix_single_page_tab_policies_is_visible') ? $this->config->get('p_lodgix_single_page_tab_policies') : '',
                    $this->config->get('p_lodgix_single_page_tab_reviews_is_visible') ? $this->config->get('p_lodgix_single_page_tab_reviews') : ''
                );
            } else {
                $html = $lpd->single();
            }
        }
        return do_shortcode($html);
    }

    function get_availability_page_content() {
        $la = new LodgixAvailability(
            $this->config->get('p_lodgix_owner_id'),
            $this->config->get('p_lodgix_display_multi_instructions') == 1,
            $this->sufix
        );
        return $la->page();
    }

    function get_vacation_rentals_content() {
        $content = '';
        if ((int)$this->config->get('p_lodgix_vacation_rentals_page_' . $this->sufix) > 0) {
            $content .= '<div class="ldgxInventoryContainer">';
            $content .= $this->get_vacation_rentals_html();
            $content .= '</div>';
        }
        return $content;
    }

    function link_translated_pages()
    {
        global $sitepress,$wpdb;
        $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_en'));

        $languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE enabled = 1 and code <> 'en'");

        if ($languages)
        {

            foreach ($languages as $l)
            {
                $sql = "SELECT * FROM " . $this->lang_pages_table . " WHERE language_code = '" . $l->code . "'";

                $posts = $wpdb->get_results($sql);

                foreach($posts as $post)
                {
                    if ($post->property_id == -1)
                    {
                        $post_id = $this->config->get('p_lodgix_vacation_rentals_page_en');
                    }
                    else if ($post->property_id == -2)
                    {
                        $post_id = $this->config->get('p_lodgix_availability_page_en');
                    }
                    else if ($post->property_id == -3)
                    {
                        $post_id = $this->config->get('p_lodgix_search_rentals_page_en');
                    }
                    else
                    {
                        $post_id = (int)$wpdb->get_var($wpdb->prepare("SELECT page_id FROM " . $this->pages_table . " WHERE property_id=" . $post->property_id . ";",null));
                    }

                    $trid = (int)$wpdb->get_var($wpdb->prepare("SELECT trid FROM " . $this->translation_table . " WHERE element_id=" . $post_id . " AND language_code='en';",null));
                    $sitepress->set_element_language_details($post->page_id,'post_page',$trid,$l->code,'en');
                }


                $translated_areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
                if (is_array($translated_areas_pages) && is_array($areas_pages)) {
                    foreach($translated_areas_pages as $translated_page)
                    {
                        foreach($areas_pages as $page)
                        {
                            if ($translated_page->area == $page->area)
                            {
                                $trid = (int)$wpdb->get_var($wpdb->prepare("SELECT trid FROM " . $this->translation_table . " WHERE element_id=" . $page->page_id . " AND language_code='en';",null));
                                $sitepress->set_element_language_details($translated_page->page_id,'post_page',$trid,$l->code,'en');
                            }
                        }
                    }
                }
            }
        }
    }

    function set_thesis_2_custom_templates_for_page($page_id) {

        $thesis_skin = get_option('thesis_skin');
        if ($thesis_skin) {
            $class = $thesis_skin['class'];
            $thesis_classic_r_templates = get_option('thesis_classic_r_templates');

            $template = Array('template' => $this->config->get('p_lodgix_thesis_2_template'));

            if ($template != '') {
                add_post_meta($page_id,  '_' . $class, $template, true);
                $meta_values = update_post_meta($page_id,  '_' . $class, $template);
            }
            else {
                delete_post_meta($page_id,  '_' . $class);
            }
        }
    }

    function set_thesis_2_custom_templates() {

        global $wpdb;

        $this->set_thesis_2_custom_templates_for_page($this->config->get('p_lodgix_vacation_rentals_page_en'));
        $this->set_thesis_2_custom_templates_for_page($this->config->get('p_lodgix_availability_page_en'));
        $this->set_thesis_2_custom_templates_for_page($this->config->get('p_lodgix_search_rentals_page_en'));


        $posts = $wpdb->get_results('SELECT * FROM ' . $this->pages_table);
        foreach($posts as $post)
        {
            $this->set_thesis_2_custom_templates_for_page($post->page_id);
        }

        $posts_de = $wpdb->get_results('SELECT * FROM ' . $this->lang_pages_table);
        foreach($posts_de as $post)
        {
          $this->set_thesis_2_custom_templates_for_page($post->page_id);
        }

        $active_languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
        foreach ($active_languages as $l) {
            $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            foreach((array)$areas_pages as $key => $page)
            {
                $this->set_thesis_2_custom_templates_for_page((int)$page->page_id);
            }
        }

    }

    function build_individual_pages() {
        global $wpdb;

        $properties = $wpdb->get_results('SELECT * FROM ' . $this->properties_table . ' ORDER BY `order`');
        if ($properties)
        {
            foreach($properties as $property)
            {
              $exists = get_post($property->post_id);

                if (!$exists)
                {
                    $post = array();
                    $post['post_name'] = sanitize_title_with_dashes($property->property_name, '', 'sav‌​e');
                    $post['post_title'] = $property->description;
                    $post['post_parent'] = (int)$this->config->get('p_lodgix_vacation_rentals_page_en');
                    $post['post_status'] = 'pending';
                    $post['post_author'] = 1;
                    $post['post_type'] = "page";
                    if ($this->config->get('p_lodgix_vacation_rentals_page_en') != NULL)
                    {
                        $post_id = wp_insert_post( $post );
                        $sql = "UPDATE " . $this->properties_table . " SET post_id=" . $post_id . " WHERE id=" . $property->id;
                        $wpdb->query($sql);
                        $sql = "INSERT INTO " . $this->pages_table . "(page_id,property_id,parent_page_id) VALUES(" . $post_id . "," . $property->id."," . $post['post_parent'] . ")";
                        $wpdb->query($sql);

                    }
                }

                $active_languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE enabled = 1 and code <> 'en'");

                foreach ($active_languages as $l) {

                    $post_id = $wpdb->get_var("SELECT page_id FROM " . $this->lang_pages_table . " WHERE property_id=" . $property->id . " AND language_code='" . $l->code . "'");
                    $exists = get_post($post_id);
                    if (!$exists)
                    {
                        $post = array();
                        $post['post_title'] = $property->description;
                        $post['post_parent'] = (int)$this->config->get('p_lodgix_vacation_rentals_page_' . $l->code);
                        $post['post_status'] = 'pending';
                        $post['post_author'] = 1;
                        $post['post_type'] = "page";

                        if ($this->config->get('p_lodgix_vacation_rentals_page_' . $l->code) != NULL)
                        {

                            $post_id = (int)$wpdb->get_var($wpdb->prepare("SELECT post_id FROM " . $this->properties_table . " WHERE id=" . $property->id . ";",null));
                            $trid = (int)$wpdb->get_var($wpdb->prepare("SELECT trid FROM " . $this->translation_table . " WHERE element_id=" . $post_id . " AND language_code='en';",null));
                            $post['post_parent'] = (int)$this->config->get('p_lodgix_vacation_rentals_page_' . $l->code);
                            $post_id = wp_insert_post( $post );
                            $sql = "INSERT INTO " . $this->lang_pages_table . "(page_id,property_id,source_page_id,language_code) VALUES(" . $post_id . "," . $property->id."," . $post_id   . ",'" . $l->code . "')";
                            $wpdb->query($sql);
                            update_post_meta($post_id, '_icl_translation', 1);

                        }
                    }
                }
            }
         }


         $properties = $wpdb->get_results('SELECT * FROM ' . $this->properties_table . ' ORDER BY `order`');
         if ($properties)
         {
            foreach($properties as $property)
            {
                if ($property->post_id != NULL)
                {

                    $post = array();
                    $post['ID'] = $property->post_id;
                    $post['post_title'] = $property->description;
                    $single_property = '[lodgix_single_property ' . $property->id . ']';
                    $post['post_content'] = $single_property;
                    $post['post_status'] = 'publish';
                    $post_id = wp_update_post($post);



                    $posts_table = $wpdb->prefix . "posts";
                    $sql = "UPDATE " . $posts_table . " SET post_content='" . $wpdb->_real_escape($single_property) . "' WHERE id=" . $post_id;
                    $wpdb->query($sql);
                    add_post_meta($post_id, 'thesis_description', trim(wptexturize($this->truncate_text($property->description_long,150))), true);
                    update_post_meta($post_id , 'thesis_description', trim(wptexturize($this->truncate_text($property->description_long,150))));
                    $keywords = $property->description . ', vacation rental, vacation home, vacation, homes, rentals, cottages, condos, holiday';
                    if ($property->city != "")
                    $keywords .= ', ' . $property->city;
                    add_post_meta($post_id, 'thesis_keywords', trim(wptexturize($keywords)), true);
                    update_post_meta($post_id , 'thesis_keywords', trim(wptexturize($keywords)));


                    $active_languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE enabled = 1 and code <> 'en'");

                    foreach ($active_languages as $l) {

                        $post_id = $wpdb->get_var("SELECT page_id FROM " . $this->lang_pages_table . " WHERE property_id=" . $property->id . " AND language_code='" . $l->code . "'");

                        $post = array();
                        $post['ID'] = $post_id;
                        $post['post_title'] = $wpdb->get_var("SELECT description FROM " . $this->lang_properties_table . " WHERE id =" . $property->id . " AND language_code='" . $l->code. "'");
                        if ($post['post_title'] == '')
                          $post['post_title'] = $property->description;
                        $single_property = '[lodgix_single_property ' . $property->id . ']';
                        $post['post_status'] = 'publish';
                        $post['post_content'] = htmlspecialchars($single_property);
                        $post_id = wp_update_post($post);
                        $sql = "UPDATE " . $this->translation_table . " SET trid=" . $trid . ", language_code='" . $l->code . "' WHERE element_id=" . $post_id;
                        $wpdb->query($sql);
                        $sql = "UPDATE " . $posts_table . " SET post_content='" . $wpdb->_real_escape($single_property) . "' WHERE id=" . $post_id;
                        $wpdb->query($sql);
                    }
                }
            }
        }


        $this->link_translated_pages();


        if ($this->config->get('p_lodgix_thesis_2_compatibility')) {
           $this->set_thesis_2_custom_templates();
        }
    }

    function remove_thesis_page($page_id)
    {
        if ($this->config->get('p_lodgix_thesis_compatibility') || $this->config->get('p_lodgix_thesis_2_compatibility'))
        {
          $thesis_options = get_option('thesis_options');
          unset($thesis_options->nav['pages'][$page_id]);
          update_option('thesis_options',$thesis_options);
        }
    }

    function p_lodgix_custom_search_get_details()
    {
        global $wpdb;

        $areas = $wpdb->get_results('SELECT DISTINCT area FROM ' . $this->properties_table . ' WHERE area <> \'\' AND area IS NOT NULL');
        $date_format = $this->config->get('p_lodgix_date_format');

        if ($date_format == '%m/%d/%Y')
           $date_format = 'mm/dd/yy';
        else if ($date_format == '%d/%m/%Y')
           $date_format = 'dd/mm/yy';
        else if ($date_format == '%m-%d-%Y')
           $date_format = 'mm-dd-yy';
        else if ($date_format == '%d-%m-%Y')
           $date_format = 'dd-mm-yy';
        else if ($date_format == '%d %b %Y')
           $date_format = 'dd M yy';

        $post_id = (int)$this->config->get('p_lodgix_search_rentals_page');

        $post_url = get_permalink($post_id);

        $max_rooms = (int)$wpdb->get_var("SELECT MAX(bedrooms) FROM " . $this->properties_table);

        $areas_json = array();
        foreach($areas as $area)
        {
            array_push($areas_json, $area->area);
        }

        $json = array('date_format' => $date_format, 'max_rooms' => $max_rooms, 'post_url' => $post_url, 'areas' => $areas_json);
        $json =  json_encode($json);

        die($json);
    }

    function p_lodgix_custom_search() {
        global $wpdb;
        $this->p_lodgix_load_locale();

        $arrival = isset($_POST['lodgix-custom-search-arrival']) && $_POST['lodgix-custom-search-arrival'] !== '' ? @esc_sql($_POST['lodgix-custom-search-arrival']) : '';
        $nights = isset($_POST['lodgix-custom-search-nights']) && $_POST['lodgix-custom-search-nights'] !== '' ? @esc_sql($_POST['lodgix-custom-search-nights']) : '1';
        $area = isset($_POST['lodgix-custom-search-area']) && $_POST['lodgix-custom-search-area'] !== '' ? @esc_sql($_POST['lodgix-custom-search-area']) : 'ALL_AREAS';
        $bedrooms = isset($_POST['lodgix-custom-search-bedrooms']) && $_POST['lodgix-custom-search-bedrooms'] !== '' ? @esc_sql($_POST['lodgix-custom-search-bedrooms']) : '0';
        $priceFrom = isset($_POST['lodgix-custom-search-daily-price-from']) ? (int)$_POST['lodgix-custom-search-daily-price-from'] : 0;
        $priceTo = isset($_POST['lodgix-custom-search-daily-price-to']) ? (int)$_POST['lodgix-custom-search-daily-price-to'] : 0;
        $id = isset($_POST['lodgix-custom-search-id']) && $_POST['lodgix-custom-search-id'] !== '' ? @esc_sql($_POST['lodgix-custom-search-id']) : '';

        $available = 'ALL';
        if ((strtotime($arrival) !== false) && (is_numeric($nights))) {
            $departure = date('Y-m-d', strtotime($arrival . ' + ' . $nights . ' days'));
            $fetch_url = 'http://www.lodgix.com/system/api-lite/xml?Action=GetAvailableProperties&PropertyOwnerID=' . $this->config->get('p_lodgix_owner_id') . '&FromDate=' . $arrival . '&ToDate=' . $departure . '&Version=' . $this->p_lodgix_db_version;
            $r = new LogidxHTTPRequest($fetch_url);
            $xml = $r->DownloadToString();
            if ($xml) {
                $x = simplexml_load_string($xml);
                $available = strval($x->Results->AvailableProperties);
            }
        }

        $found = false;
        $sql =
            'SELECT COUNT(*) AS num_results, MIN(rules.mn) AS min_nights FROM ' . $this->properties_table
            . ' LEFT JOIN (SELECT property_id, MIN(min_nights) AS mn FROM ' . $this->rules_table
            . ' GROUP BY property_id) AS rules ON ' . $this->properties_table . '.id=rules.property_id WHERE 1=1 AND ';
        if (is_numeric($id)) {
            $testsql = $sql . $this->properties_table . '.id=' . $id;
            $testcount = $wpdb->get_results($testsql);
            if ($testcount[0]->num_results > 0) {
                $found = true;
                $sql .= '(' . $this->properties_table . '.id=' . $id . ' OR ' . $this->properties_table . ".description LIKE '%" . $id . "%') AND ";
            }
        }

        if (!$found) {
            if ($area != 'ALL_AREAS') {
                $sql .= $this->properties_table . ".area='" . str_replace('\\\\','',$wpdb->_real_escape($area)) . "' AND ";
            }
            if ($id != '') {
                $sql .= "UPPER(" . $this->properties_table . ".description) like '%" . $wpdb->_real_escape(strtoupper($id)) . "%' AND ";
            }
            if ($bedrooms != 'ANY') {
                $sql .= $this->properties_table . '.bedrooms>=' . $wpdb->_real_escape($bedrooms) . ' AND ';
            }
            if ($priceFrom > 0) {
                $sql .= $this->properties_table . '.min_daily_rate>=' . $priceFrom . ' AND ';
            }
            if ($priceTo > 0 && $priceTo >= $priceFrom) {
                $sql .= $this->properties_table . '.min_daily_rate<=' . $priceTo . ' AND ';
            }
        }

        if (!$available || $available == 'null') {
            $sql .= ' 1=0 AND ';
        } else if ($available != 'ALL') {
           $sql .= $this->properties_table . '.id IN (' . $wpdb->_real_escape($available) . ') AND ';
        }

        $sql .= $this->get_property_ids_with_amenities($_POST['lodgix-custom-search-amenity']);
        $sql .= ' 1=1 ';

        $count = $wpdb->get_results($sql);
        $content = json_encode($count[0]);
        die($content);
    }

    function clean_all()
    {
        global $wpdb;
        $posts = $wpdb->get_results('SELECT * FROM ' . $this->pages_table);
        foreach($posts as $post)
        {
            wp_delete_post($post->page_id, $force_delete=true);
        }

        $posts_de = $wpdb->get_results('SELECT * FROM ' . $this->lang_pages_table);
        foreach($posts_de as $post)
        {
            wp_delete_post($post->page_id, $force_delete=true);
        }


        $languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
        if ($languages)
        {
            foreach($languages as $l)
            {
                wp_delete_post((int)$this->config->get('p_lodgix_vacation_rentals_page_' . $l->code), $force_delete = true);
                wp_delete_post((int)$this->config->get('p_lodgix_availability_page_' . $l->code), $force_delete = true);
                wp_delete_post((int)$this->config->get('p_lodgix_search_rentals_page_' . $l->code), $force_delete = true);

                $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
                foreach((array)$areas_pages as $key => $page)
                {
                    wp_delete_post((int)$page->page_id, $force_delete = true);
                    unset($areas_pages[$key]);
                }

                $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize($areas_pages));
            }
        }

        $this->config->save();
        $lsdb = new LodgixServiceDB();
        $lsdb->clean();
    }

    function clean_languages($active_languages)
    {
        global $wpdb;

        $sql = "SELECT * FROM " . $this->lang_pages_table . " WHERE language_code NOT IN (" . $active_languages . ")";
        $posts = $wpdb->get_results($sql);

        foreach($posts as $post)
        {
            wp_delete_post($post->page_id, $force_delete = true);
        }

        $wpdb->query("DELETE FROM " . $this->lang_pages_table . " WHERE language_code NOT IN (" . $active_languages . ")");

        $languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE code NOT IN (" . $active_languages . ")");

        if (is_array($languages)) {
            foreach ($languages as $l){

                wp_delete_post((int)$this->config->get('p_lodgix_vacation_rentals_page_' . $l->code), $force_delete = true);
                wp_delete_post((int)$this->config->get('p_lodgix_availability_page_' . $l->code), $force_delete = true);
                wp_delete_post((int)$this->config->get('p_lodgix_search_rentals_page_' . $l->code), $force_delete = true);
                $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
                if (is_array($areas_pages) && count($areas_pages) > 0) {
                    foreach($areas_pages as $page)
                    {
                        wp_delete_post((int)$page->page_id, $force_delete = true);
                    }
                }

                $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize(array()));
                $this->config->save();
            }
        }
    }

    function fetchData($url) {
        $r = new LogidxHTTPRequest($url);
        $xml = $r->DownloadToString();
        $x = simplexml_load_string($xml);
        return $x;
    }

    function reschedule_notify() {
        wp_clear_scheduled_hook('p_lodgix_notify');
        wp_schedule_single_event(time()+900, 'wp_ajax_nopriv_p_lodgix_notify');
    }

    function p_lodgix_notify() {
        ini_set('max_execution_time', 0);

        $ownerData = $this->fetchData($this->getOwnerFetchUrl());
        $propertyData = $this->fetchData($this->getFetchUrl());

        if (!empty($ownerData) && !empty($propertyData)) {
            if ($ownerData->Error) {
                $this->reschedule_notify();
                die("ERROR");
            } else {
                $lp = new LodgixParser($this->config);
                $lp->processFetchedData($ownerData, $propertyData);
                $this->build_individual_pages();
                // $this->build_areas_pages();
                die("OK");
            }
        } else {
            $this->reschedule_notify();
            die("ERROR");
        }
    }

    function p_lodgix_geturls() {
        header("Content-type: text/xml");
        global $wpdb;
        ini_set('max_execution_time', 0);
        $posts = $wpdb->get_results('SELECT * FROM ' . $this->pages_table);
        print "<Properties>";
        foreach($posts as $post)
        {
            print "<Property>";
            print "<ID>" . $post->property_id . "</ID>";
            print '<URL>' .  htmlentities(urlencode(get_permalink($post->page_id))) . '</URL>';

            $lposts = $wpdb->get_results('SELECT * FROM ' . $this->lang_pages_table . ' WHERE property_id=' . $post->property_id);
            foreach($lposts as $lpost)
            {
                print '<URL' . strtoupper($lpost->language_code) . '>' . htmlentities(urlencode(get_permalink($lpost->page_id))) . '</URL' . strtoupper($lpost->language_code) . '>';
            }
            print "</Property>";
        }
        print "</Properties>";

        die("");
    }


    function p_lodgix_check() {
        ini_set('max_execution_time', 0);
        die("PLUGIN_INSTALLED");
    }

    function set_page_options()
    {
        global $wpdb;

        $active_languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
        foreach ($active_languages as $l) {

            $post_id = (int)$this->config->get('p_lodgix_vacation_rentals_page_' . $l->code);
            $post = array();
            $post['ID'] = $post_id;
            $exists = get_post($post_id);
            if ($exists)
            {
                if ($this->config->get('p_lodgix_allow_comments')) $post['comment_status'] = 'open';
                else $post['comment_status'] = 'closed';
                if ($this->config->get('p_lodgix_allow_pingback')) $post['ping_status'] = 'open';
                else $post['ping_status'] = 'closed';
                wp_update_post($post);
            }

            $post_id = (int)$this->config->get('p_lodgix_availability_page_' . $l->code);
            $post = array();
            $post['ID'] = $post_id;
            $exists = get_post($post_id);
            if ($exists)
            {
                if ($this->config->get('p_lodgix_allow_comments')) $post['comment_status'] = 'open';
                else $post['comment_status'] = 'closed';
                if ($this->config->get('p_lodgix_allow_pingback')) $post['ping_status'] = 'open';
                else $post['ping_status'] = 'closed';
                wp_update_post($post);
            }

            $post_id = (int)$this->config->get('p_lodgix_search_rentals_page_' . $l->code);
            $post = array();
            $post['ID'] = $post_id;
            $exists = get_post($post_id);
            if ($exists)
            {
                if ($this->config->get('p_lodgix_allow_comments')) $post['comment_status'] = 'open';
                else $post['comment_status'] = 'closed';
                if ($this->config->get('p_lodgix_allow_pingback')) $post['ping_status'] = 'open';
                else $post['ping_status'] = 'closed';
                wp_update_post($post);
            }

        }

        $pages = $wpdb->get_results('SELECT * FROM ' . $this->pages_table);
        foreach($pages as $page)
        {
            $post_id = $page->page_id;
            $post = array();
            $post['ID'] = $post_id;
            $exists = get_post($post_id);
            if ($exists)
            {
                if ($this->config->get('p_lodgix_allow_comments'))
                    $post['comment_status'] = 'open';
                else $post['comment_status'] = 'closed';
                if ($this->config->get('p_lodgix_allow_pingback')) $post['ping_status'] = 'open';
                else $post['ping_status'] = 'closed';
                wp_update_post($post);
            }
        }


        $active_languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE enabled = 1");
        foreach ($active_languages as $l) {
            $pages = $wpdb->get_results("SELECT * FROM " . $this->lang_pages_table . " WHERE language_code='" . $l->code . "'");
            foreach($pages as $page)
            {
                $post_id = $page->page_id;
                $post = array();
                $post['ID'] = $post_id;
                $exists = get_post($post_id);
                if ($exists)
                {
                    if ($this->config->get('p_lodgix_allow_comments')) $post['comment_status'] = 'open';
                    else $post['comment_status'] = 'closed';
                    if ($this->config->get('p_lodgix_allow_pingback')) $post['ping_status'] = 'open';
                    else $post['ping_status'] = 'closed';
                    wp_update_post($post);
                }
            }

            $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));

            if (is_array($areas_pages)) {

                foreach($areas_pages as $page)
                {
                    $post_id = $page->page_id;
                    $post = array();
                    $post['ID'] = $post_id;
                    $exists = get_post($post_id);
                    if ($exists)
                    {
                        if ($this->config->get('p_lodgix_allow_comments'))
                            $post['comment_status'] = 'open';
                        else
                            $post['comment_status'] = 'closed';
                        if ($this->config->get('p_lodgix_allow_pingback'))
                            $post['ping_status'] = 'open';
                        else
                            $post['ping_status'] = 'closed';
                        wp_update_post($post);
                    }
                }
            }

            $this->link_translated_pages();
        }
    }

    function p_lodgix_build() {
        $lsdb = new LodgixServiceDB();
        $lsdb->create();
        add_option(LodgixConst::OPTION_DB_VERSION, $this->p_lodgix_db_version);
    }

    /**
    * Updates Database
    **/
    function update_db($old_db_version) {
        global $wpdb;

        if ($old_db_version < 1.2)
        {
            $pictures_path = WP_CONTENT_DIR.'/lodgix_pictures';
            $this->rrmdir($pictures_path);
        }

        if ($old_db_version < 1.3)
        {
            $sql = "ALTER TABLE " . $this->properties_table  . " MODIFY COLUMN `bathrooms` float default '0';";
            $wpdb->query($sql);
        }

        if ($old_db_version < 1.4)
        {
            $sql = "ALTER TABLE " . $this->pictures_table  . " MODIFY COLUMN `caption` varchar(255) default NULL;";
            $wpdb->query($sql);
        }

        if ($old_db_version < 1.5)
        {
            $sql = "ALTER TABLE " . $this->properties_table  . " ADD COLUMN `video_url` text default NULL;";
            $wpdb->query($sql);
            $sql = "ALTER TABLE " . $this->properties_table  . " ADD COLUMN `virtual_tour_url` text default NULL;";
            $wpdb->query($sql);
        }

        if ($old_db_version < 1.6)
        {
            $sql = "ALTER TABLE " . $this->properties_table  . " ADD COLUMN `beds_text` text default NULL;";
            $wpdb->query($sql);
        }

        if ($old_db_version < 1.7)
        {
            $this->build_individual_pages();
        }

        if ($old_db_version < 1.8)
        {
             $table_name = $wpdb->prefix . "lodgix_link_rotators";
             if($wpdb->get_var("show tables like '$table_name'") != $table_name) {
                    $sql = "CREATE TABLE " . $table_name . " (
                        `id` int(11) NOT NULL auto_increment,
                        `url` varchar(255) NOT NULL DEFAULT '',
                        `title` varchar(255) DEFAULT NULL,
                        PRIMARY KEY (`id`)
             );";
             $wpdb->query($sql);
            }
        }

        if ($old_db_version < 1.9) {
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_lang_amenities ADD COLUMN searchable tinyint(1) NOT NULL default 0;");
        }

        if ($old_db_version < 2.0) {
            $this->config->set('p_lodgix_vacation_rentals_page_en', $this->config->get('p_lodgix_vacation_rentals_page'));
            $this->config->set('p_lodgix_contact_url_en', $this->config->get('p_lodgix_contact_url'));
            $this->config->set('p_lodgix_search_rentals_page_en', $this->config->get('p_lodgix_search_rentals_page'));
            $this->config->set('p_lodgix_availability_page_en', $this->config->get('p_lodgix_availability_page'));
            $this->config->set('p_lodgix_areas_pages_en', $this->config->get('p_lodgix_areas_pages'));
            if ($this->config->get('p_lodgix_generate_german'))
            {
                $wpdb->query("UPDATE " . $this->languages_table . " SET enabled=1 WHERE code = 'de'");
            }

            $languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table);

            foreach ($languages as $l) {
                $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
                if (!is_array($areas_pages))
                    $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize(array()));
            }

            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_lang_amenities ADD COLUMN `language_code` varchar(2);");
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_lang_amenities CHANGE COLUMN `description_de` `description_translated` varchar(255) DEFAULT NULL;");
            $wpdb->query("UPDATE " . $wpdb->prefix . "lodgix_lang_amenities SET language_code = 'de';");

            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_lang_properties DROP PRIMARY KEY, ADD PRIMARY KEY(`id`,`language_code`);");

            $this->config->save();
            wp_redirect($_SERVER["REQUEST_URI"]);
        }

        if ($old_db_version < 2.1) {

            $old = get_option('widget_lodgix_custom_search');
            update_option('old_widget_lodgix_custom_search',$old);

            $old = get_option('widget_lodgix_custom_search_2');
            update_option('old_widget_lodgix_custom_search_2',$old);

            $old = get_option('widget_lodgix_featured');
            update_option('old_widget_lodgix_featured',$old);

            update_option('widget_lodgix_custom_search',array());
            update_option('widget_lodgix_custom_search_2',array());
            update_option('widget_lodgix_featured',array());

            $sidebars = get_option('sidebars_widgets');
            $counter = 20;
            foreach($sidebars as $key => $value) {
                $widget_counter = 0;
                if (is_array($sidebars[$key])) {
                    foreach($sidebars[$key] as $widget) {


                        if ($widget == 'rentals-search' || $widget == 'rentals-search-2' || $widget == 'featured-rentals')
                        {

                            $amenities = 0;
                            if ($widget == 'rentals-search' || $widget == 'rentals-search-2') {
                                $sidebars[$key][$widget_counter] = 'lodgix_custom_search-' . $counter;
                                $old_widget = get_option('old_widget_lodgix_custom_search');
                                if ($widget == 'rentals-search-2') {
                                    $old_widget = get_option('old_widget_lodgix_custom_search_2');
                                }

                                $amenities = $old_widget['amenities'];
                                $title = $old_widget['title'];

                                $w = get_option('widget_lodgix_custom_search');
                                $w[$counter] = array(
                                    'title' => $title,
                                    'amenities' =>  $amenities
                                );
                                update_option('widget_lodgix_custom_search',$w);
                            }
                            else {

                                $sidebars[$key][$widget_counter] = 'lodgix_featured-' . $counter;
                                $old_widget = get_option('old_widget_lodgix_featured');
                                $title = $old_widget['title'];

                                $w = get_option('widget_lodgix_featured');
                                $w[$counter] = array(
                                        'title' => $title
                                );

                                update_option('widget_lodgix_featured',$w);

                            }


                            $counter ++;
                        }
                        $widget_counter++;
                    }
                }

            }

            update_option('sidebars_widgets',$sidebars);
            wp_redirect($_SERVER["REQUEST_URI"]);
        }


        if ($old_db_version < 2.2) {
            $this->config->set('p_lodgix_display_weekly_rates', true);
            $this->config->set('p_lodgix_display_monthly_rates', true);
            $this->config->save();
        }

        if ($old_db_version < 2.4) {
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_rates ADD COLUMN  `weekend_rate` decimal(10,2);");
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_rates ADD COLUMN `weekend_rate_enabled` tinyint(1) NOT NULL default '0'");
        }

        if ($old_db_version < 2.5) {

            if ($this->config->get('p_lodgix_custom_page_template') && $this->config->get('p_lodgix_custom_page_template') != '') {
                $this->config->set('p_lodgix_page_template', 'CUSTOM');
                $this->config->save();
            }
        }

        if ($old_db_version < 2.6) {
            $this->config->set('p_lodgix_gmap_zoom_level', 0);
            $this->config->save();
        }

        if ($old_db_version < 2.7) {
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_amenities ADD UNIQUE `property_id`(`property_id`, `description`)");
        }

        if ($old_db_version < 2.8) {
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_reviews ADD (stars INTEGER NOT NULL DEFAULT 5, title LONGTEXT NOT NULL DEFAULT '')");
        }

        if ($old_db_version < 2.9) {
            $wpdb->query("ALTER TABLE " . $wpdb->prefix . "lodgix_properties ADD (allow_same_day_booking TINYINT NOT NULL DEFAULT 1, limit_booking_days_advance SMALLINT NOT NULL DEFAULT 0)");
        }

        if ($old_db_version < 3.0) {
            $wpdb->query("ALTER TABLE $this->properties_table ADD property_name TEXT");
        }

        if ($old_db_version < 3.1) {
            $wpdb->query("ALTER TABLE $this->properties_table ADD property_title TEXT");
        }

        if ($old_db_version < 3.2) {
            $wpdb->query("DROP TABLE  " . $wpdb->prefix . "lodgix_rates");
        }
    }

    function getOwnerFetchUrl() {
        return
            'https://www.lodgix.com/api/xml/owners/get?Token='
            . $this->config->get('p_lodgix_api_key')
            . '&IncludeLanguages=Yes&IncludeRotators=Yes&IncludeAmenities=Yes&OwnerID='
            . $this->config->get('p_lodgix_owner_id')
            . '&Version=' . $this->p_lodgix_db_version;
    }

    function getFetchUrl() {
        return
            'https://www.lodgix.com/api/xml/properties/get?Token='
            . $this->config->get('p_lodgix_api_key')
            . '&IncludeAmenities=Yes&IncludePhotos=Yes&IncludeConditions=Yes&IncludeLanguages=Yes&IncludeTaxes=Yes&IncludeReviews=Yes&IncludeMergedRates=Yes&OwnerID='
            . $this->config->get('p_lodgix_owner_id')
            . '&Version=' . $this->p_lodgix_db_version;
    }

    /**
    * Returns Last Index
    **/
    function lastIndexOf($substr, $str){
        if(false !== ($r = strpos(strrev($str), strrev($substr))))
            return strlen($str)-$r-strlen($substr);
        return false;
    }

    /**
    * Truncates text
    **/
    function truncate_text($text,$limit)
    {
        if (strlen($text) < $limit)
            return $text;

        $text = substr ($text, 0,$limit-1);
        $text = substr ($text, 0,$this->lastIndexOf(' ',$text));
        return $text . '.';
    }

    /**
    * Delete Folder
    **/
    function rrmdir($dir) {
        if (is_dir($dir)) {
            $objects = scandir($dir);
            foreach ($objects as $object) {
                if ($object != "." && $object != "..") {
                    if (filetype($dir."/".$object) == "dir") $this->rrmdir($dir."/".$object); else unlink($dir."/".$object);
                }
            }
            reset($objects);
            rmdir($dir);
       }
    }



    /**
    * Clears Posts Revisions
    */
    function clear_revisions() {
        global $wpdb;

        if ($this->config->get('p_lodgix_vacation_rentals_page_en'))
        {
            $sql = "DELETE a,b,c FROM " . $wpdb->prefix  . "posts a LEFT JOIN " . $wpdb->prefix  . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix  . "postmeta c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $this->config->get('p_lodgix_vacation_rentals_page_en');
            $wpdb->query($sql);
        }
        if ($this->config->get('p_lodgix_availability_page_en'))
        {
            $sql = "DELETE a,b,c FROM " . $wpdb->prefix  . "posts a LEFT JOIN " . $wpdb->prefix  . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix  . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $this->config->get('p_lodgix_availability_page_en');
            $wpdb->query($sql);
        }
        if ($this->config->get('p_lodgix_search_rentals_page_en'))
        {
            $sql = "DELETE a,b,c FROM " . $wpdb->prefix  . "posts a LEFT JOIN " . $wpdb->prefix  . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix  . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $this->config->get('p_lodgix_search_rentals_page_en');
            $wpdb->query($sql);
        }


        $posts = $wpdb->get_results('SELECT * FROM ' . $this->pages_table);
        foreach($posts as $post)
        {
            $sql = "DELETE a,b,c FROM " . $wpdb->prefix  . "posts a LEFT JOIN " . $wpdb->prefix  . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix  . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $post->page_id;
            $wpdb->query($sql);
        }

        $active_languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE enabled = 1 and code <> 'en'");
        if (count($active_languages) > 0)
        {
            foreach($active_languages as $l) {
                if ($this->config->get('p_lodgix_vacation_rentals_page_' . $l->code)) {
                    $sql = "DELETE a,b,c FROM " . $wpdb->prefix . "posts a LEFT JOIN " . $wpdb->prefix . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $this->config->get('p_lodgix_vacation_rentals_page_' . $l->code);
                    $wpdb->query($sql);
                }

                if ($this->config->get('p_lodgix_availability_page_' . $l->code)) {
                    $sql = "DELETE a,b,c FROM " . $wpdb->prefix . "posts a LEFT JOIN " . $wpdb->prefix . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $this->config->get('p_lodgix_availability_page_' . $l->code);
                    $wpdb->query($sql);
                }

                if ($this->config->get('p_lodgix_search_rentals_page_' . $l->code)) {
                    $sql = "DELETE a,b,c FROM " . $wpdb->prefix . "posts a LEFT JOIN " . $wpdb->prefix . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $this->config->get('p_lodgix_search_rentals_page_' . $l->code);
                    $wpdb->query($sql);
                }


                $posts = $wpdb->get_results("SELECT * FROM " . $this->lang_pages_table . " WHERE language_code = '" . $l->code . "'");
                foreach ($posts as $post) {
                    $sql = "DELETE a,b,c FROM " . $wpdb->prefix . "posts a LEFT JOIN " . $wpdb->prefix . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $post->page_id;
                    $wpdb->query($sql);
                }
            }
        }

        $active_languages = $wpdb->get_results("SELECT * FROM " . $this->languages_table . " WHERE enabled = 1");
        foreach($active_languages as $l) {
            $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            if (is_array($areas_pages) && count($areas_pages) > 0) {
                foreach($areas_pages as $page) {
                    if ($page->page_id) {
                        $sql = "DELETE a,b,c FROM " . $wpdb->prefix  . "posts a LEFT JOIN " . $wpdb->prefix  . "term_relationships b ON (a.ID = b.object_id) LEFT JOIN " . $wpdb->prefix  . "postmeta  c ON (a.ID = c.post_id) WHERE a.post_type = 'revision' AND a.post_parent=" . $page->page_id;
                        $wpdb->query($sql);
                    }
                }
            }
        }
    }

    function p_lodgix_save_settings() {
        global $wpdb;
        $json = array('result' => 'FAIL', 'msg' => 'Undefined Error!');

        if (current_user_can('manage_options') && $_POST['p_lodgix_save']) {
            ini_set('max_execution_time', 0);

            $this->p_lodgix_build();

            if (!wp_verify_nonce($_POST['_wpnonce'], 'p_lodgix-update-options')) {
                die('Whoops! There was a problem with the data you posted. Please go back and try again.');
            }
            if (($this->config->get('p_lodgix_owner_id') != ((int)$_POST['p_lodgix_owner_id'])) || ($this->config->get('p_lodgix_display_title') != $_POST['p_lodgix_display_title'])) {
                $this->clean_all();
            }

            $this->clear_revisions();

            $lsa = new LodgixServiceAdmin($this->config, $_POST);
            $reload = $lsa->saveConfig();

            // Language related

            $active_languages = array("'en'");
            $languages = $wpdb->get_results("SELECT * FROM $this->languages_table");
            if ($languages) {
                foreach ($languages as $l) {
                    if (isset($_POST['p_lodgix_contact_url_' . $l->code])) {
                        $this->config->set('p_lodgix_contact_url_' . $l->code, $_POST['p_lodgix_contact_url_' . $l->code]);
                    }
                    if ($_POST['p_lodgix_generate_' . $l->code] && ($l->code != 'en')) {
                        array_push($active_languages, "'$l->code'");
                    }
                }
                $active_languages = implode(',', $active_languages);
                $wpdb->query("UPDATE $this->languages_table SET enabled=0 WHERE code NOT IN ($active_languages)");
                $wpdb->query("UPDATE $this->languages_table SET enabled=1 WHERE code IN ($active_languages)");
                $this->clean_languages($active_languages);
            }

            $this->p_lodgix_set_page_titles();

            $languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
            if ($languages) {
                foreach ($languages as $l) {
                    $post = array();
                    $post['post_title'] = $this->page_titles[$l->code]['vacation_rentals'];
                    $post['menu_order'] = 1;
                    $post['post_status'] = 'publish';
                    $post['post_content'] = '[lodgix_vacation_rentals]';
                    $post['post_author'] = 1;
                    $post['post_type'] = "page";
                    $exists = get_post($this->config->get('p_lodgix_vacation_rentals_page_' . $l->code));
                    if (!$exists) {
                        $post_de_id = wp_insert_post( $post );
                        if ($post_de_id != 0) {
                            $this->config->set('p_lodgix_vacation_rentals_page_' . $l->code, (int)$post_de_id);
                            if ($l->code != 'en') {
                                $sql = "INSERT INTO " . $this->lang_pages_table . "(page_id,property_id,source_page_id,language_code) VALUES(" . $post_de_id . ",-1,NULL,'" . $l->code ."')";
                                $wpdb->query($sql);
                            }
                        }
                    } else {
                        $post = array();
                        $post['post_title'] = $this->page_titles[$l->code]['vacation_rentals'];
                        $post['post_name'] = sanitize_title($post['post_title']);
                        $post['post_content'] = '[lodgix_vacation_rentals]';
                        $post['ID'] = $this->config->get('p_lodgix_vacation_rentals_page_' . $l->code);
                        $post_id = wp_update_post($post);
                        $posts_table = $wpdb->prefix . "posts";
                        $sql = "UPDATE " . $posts_table . " SET post_content='[lodgix_vacation_rentals]' WHERE id=" . $post_id;
                        $wpdb->query($sql);
                    }
                }
            }

            $this->config->save();

            if ($this->config->get('p_lodgix_thesis_compatibility') || $this->config->get('p_lodgix_thesis_2_compatibility')) {
                delete_post_meta($this->config->get('p_lodgix_vacation_rentals_page_en'), 'thesis_title');
                delete_post_meta($this->config->get('p_lodgix_vacation_rentals_page_en'), 'thesis_description');
                delete_post_meta($this->config->get('p_lodgix_vacation_rentals_page_en'), 'thesis_keywords');
            }

            $languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
            if ($languages) {
                foreach ($languages as $l) {
                    $post = array();
                    $post['menu_order'] = 2;
                    $post['post_title'] =  $this->page_titles[$l->code]['availability'];
                    $post['post_content'] = '[lodgix_availability]';
                    $post['post_status'] = 'publish';
                    $post['post_type'] = "page";
                    $exists = get_post($this->config->get('p_lodgix_availability_page_' . $l->code));
                    if (!$exists) {
                        $post_id = wp_insert_post( $post );
                        if ($post_de_id != 0) {
                            $this->config->set('p_lodgix_availability_page_' . $l->code, (int)$post_id);
                            if ($l->code != 'en') {
                                $sql = "INSERT INTO " . $this->lang_pages_table . "(page_id,property_id,source_page_id,language_code) VALUES(" . $post_id . ",-2,NULL,'" . $l->code . "')";
                                $wpdb->query($sql);
                            }
                        }
                    } else {
                        $post = array();
                        $post['post_title'] =  $this->page_titles[$l->code]['availability'];
                        $post['post_name'] = '';
                        $post['post_content'] = '[lodgix_availability]';
                        $post['ID'] = $this->config->get('p_lodgix_availability_page_' . $l->code);
                        $post_id = wp_update_post($post);
                        $posts_table = $wpdb->prefix . "posts";
                        $sql = "UPDATE " . $posts_table . " SET post_content='[lodgix_availability]' WHERE id=" . $post_id;
                        $wpdb->query($sql);
                    }
                }
            }

            $languages = $wpdb->get_results('SELECT * FROM ' . $this->languages_table . ' WHERE enabled = 1');
            if ($languages) {
                foreach ($languages as $l) {
                    $post = array();
                    $post['post_title'] =  $this->page_titles[$l->code]['search'];
                    $post['post_content'] = '[lodgix_search_rentals]';
                    $post['post_status'] = 'publish';
                    $post['post_type'] = "page";
                    $exists = get_post($this->config->get('p_lodgix_search_rentals_page_' . $l->code));
                    if (!$exists) {
                        $post_de_id = wp_insert_post( $post,true );
                        if ($post_de_id != 0) {
                            $this->config->set('p_lodgix_search_rentals_page_' . $l->code, (int)$post_de_id);
                            if ($l->code != 'en') {
                                $sql = "INSERT INTO " . $this->lang_pages_table . "(page_id,property_id,source_page_id,language_code) VALUES(" . $post_de_id . ",-3,NULL,'" . $l->code . "')";
                                $wpdb->query($sql);
                            }
                        }
                    } else {
                        $post = array();
                        $post['post_title'] =  $this->page_titles[$l->code]['search'];
                        $post['post_name'] = '';
                        $post['post_content'] = '[lodgix_search_rentals]';
                        $post['ID'] = $this->config->get('p_lodgix_search_rentals_page_' . $l->code);
                        $post_id = wp_update_post($post);
                        $posts_table = $wpdb->prefix . "posts";
                        $sql = "UPDATE " . $posts_table . " SET post_content='[lodgix_search_rentals]' WHERE id=" . $post_id;
                        $wpdb->query($sql);
                    }
                }
            }

            $this->config->save();

            $ownerData = $this->fetchData($this->getOwnerFetchUrl());
            $propertyData = $this->fetchData($this->getFetchUrl());

            if (!empty($ownerData) && !empty($propertyData)) {
                if ($ownerData->Error) {
                    $json = array('result' => 'FAIL', 'msg' => 'Error: ' . strval($ownerData->Error->Message));
                    die(json_encode($json));
                } else {
                    $lp = new LodgixParser($this->config);
                    $lp->processFetchedData($ownerData, $propertyData);
                    $this->build_individual_pages();
                    $this->build_areas_pages();
                    $this->set_page_options();
                }

                $this->clear_revisions();

                $thesis_2_template_options = Array();
                array_push($thesis_2_template_options,Array('class' => '','title' => 'Default'));

                try {
                    $thesis_skin = get_option('thesis_skin');
                    if ($thesis_skin) {
                        $class = $thesis_skin['class'];
                        $thesis_classic_r_templates = get_option('thesis_classic_r_templates');
                    }

                    if ((is_array($thesis_classic_r_templates) || $thesis_classic_r_templates instanceof Traversable)) {
                        foreach ($thesis_classic_r_templates as $key => $value) {
                            $title = ucwords($key);
                                if (0 === strpos($key, 'custom_')) {
                                    $title = $value['title'];
                                }
                                array_push($thesis_2_template_options,Array('class' => $key,'title' => $title));
                        }
                    }
                } catch (SomeException $e) {}

                $json = array('result' => 'OK', 'msg' => 'Success! Your changes were sucessfully saved!');
            } else {
                $json = array('result' => 'FAIL', 'msg' => 'Error: It wasn\'t possible to connect to Lodgix. Please try again later.');
            }
        }

        if ($json['result'] == 'OK' && $reload) {
            $json['result'] = 'RELOAD';
        }

        die(json_encode($json));
    }

    function p_lodgix_clean_database() {
        if (current_user_can('manage_options') && $_POST['p_lodgix_clean']) {
            $this->clean_all();
            $lsdb = new LodgixServiceDB();
            $lsdb->drop();
            $lsc = new LodgixServiceConfig();
            $lsc->delete();
            delete_option(LodgixConst::OPTION_DB_VERSION);
        }
    }

    function admin_options_page() {
        global $wpdb;

        $this->p_lodgix_build();

        if (get_option(LodgixConst::OPTION_DB_VERSION)) {
            $old_db_version = (float)get_option(LodgixConst::OPTION_DB_VERSION);
            if ($old_db_version < (float)$this->p_lodgix_db_version) {
                $this->update_db($old_db_version);
            }
        }
        update_option(LodgixConst::OPTION_DB_VERSION, $this->p_lodgix_db_version);

        $languages = $wpdb->get_results("SELECT * FROM $this->languages_table");
        foreach ($languages as $l) {
            $areas_pages = unserialize($this->config->get('p_lodgix_areas_pages_' . $l->code));
            if (!is_array($areas_pages)) {
                $this->config->set('p_lodgix_areas_pages_' . $l->code, serialize(array()));
            }
        }
        $this->config->save();

        $las = new LodgixAdminSettings($this->config);
        echo $las->page();
    }

}
