<?php

class LodgixWidgetRentalSearch2 extends WP_Widget {

    private static $DEFAULT_SETTINGS;

    public function __construct() {
		parent::__construct(
			'lodgix_rental_search',
            __('Lodgix Rental Search'),
			array('description' => __('Lodgix Rental Search Widget'))
		);
        self::$DEFAULT_SETTINGS = array(
            'title' => 'Rental Search',
            'button_text' => 'Display Results',
            'horizontal' => false,
            'location' => true,
            'bedrooms' => true,
            'price' => true,
            'from_price' => 50,
            'to_price' => 1000,
            'price_increment' => 50,
            'currency_symbol' => '$',
            'amenities' => false,
            'name' => true
        );
	}

    public function form($instance) {
        global $wpdb;

        $tableProperties = $wpdb->prefix . 'lodgix_properties';

        $title = self::$DEFAULT_SETTINGS['title'];
        $button_text = self::$DEFAULT_SETTINGS['button_text'];
        $horizontal = self::$DEFAULT_SETTINGS['horizontal'];
        $location = self::$DEFAULT_SETTINGS['location'];
        $bedrooms = self::$DEFAULT_SETTINGS['bedrooms'];
        $price = self::$DEFAULT_SETTINGS['price'];
        $fromPrice = self::$DEFAULT_SETTINGS['from_price'];
        $toPrice = self::$DEFAULT_SETTINGS['to_price'];
        $priceIncrement = self::$DEFAULT_SETTINGS['price_increment'];
        $properties = $wpdb->get_results("SELECT currency_symbol FROM $tableProperties LIMIT 1");
        if ($properties) {
            $currencySymbol = $properties[0]->currency_symbol;
        } else {
            $currencySymbol = self::$DEFAULT_SETTINGS['currency_symbol'];
        }
        $amenities = self::$DEFAULT_SETTINGS['amenities'];
        $name = self::$DEFAULT_SETTINGS['name'];
		if ($instance) {
            if (array_key_exists('title', $instance)) {
                $title = esc_attr($instance['title']);
            }
            if (array_key_exists('button_text', $instance)) {
                $button_text = esc_attr($instance['button_text']);
            }
            if (array_key_exists('horizontal', $instance)) {
                $horizontal = esc_attr($instance['horizontal']);
            }
            if (array_key_exists('location', $instance)) {
                $location = esc_attr($instance['location']);
            }
            if (array_key_exists('bedrooms', $instance)) {
                $bedrooms = esc_attr($instance['bedrooms']);
            }
            if (array_key_exists('price', $instance)) {
                $price = esc_attr($instance['price']);
            }
            if (array_key_exists('from_price', $instance)) {
                $fromPrice = esc_attr($instance['from_price']);
            }
            if (array_key_exists('to_price', $instance)) {
                $toPrice = esc_attr($instance['to_price']);
            }
            if (array_key_exists('price_increment', $instance)) {
                $priceIncrement = esc_attr($instance['price_increment']);
            }
            if (array_key_exists('currency_symbol', $instance)) {
                $currencySymbol = esc_attr($instance['currency_symbol']);
            }
            if (array_key_exists('amenities', $instance)) {
			    $amenities = esc_attr($instance['amenities']);
            }
            if (array_key_exists('name', $instance)) {
                $name = esc_attr($instance['name']);
            }
		}
		?>
			<p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>"><br>
            </p>
			<p>
                <label for="<?php echo $this->get_field_id('button_text'); ?>"><?php _e('Button Text:'); ?></label>
                <input class="widefat" id="<?php echo $this->get_field_id('button_text'); ?>" name="<?php echo $this->get_field_name('button_text'); ?>" type="text" value="<?php echo $button_text; ?>"><br>
            </p>
            <p>
                <input id="<?php echo $this->get_field_id('horizontal'); ?>" name="<?php echo $this->get_field_name('horizontal'); ?>" type="checkbox" <?php checked(true, $horizontal); ?>>
                <label for="<?php echo $this->get_field_id('horizontal'); ?>"><?php _e('Horizontal Layout'); ?></label>
			</p>
            <p>
                <input id="<?php echo $this->get_field_id('location'); ?>" name="<?php echo $this->get_field_name('location'); ?>" type="checkbox" <?php checked(true, $location); ?>>
                <label for="<?php echo $this->get_field_id('location'); ?>"><?php _e('Search by Location'); ?></label>
			</p>
            <p>
                <input id="<?php echo $this->get_field_id('bedrooms'); ?>" name="<?php echo $this->get_field_name('bedrooms'); ?>" type="checkbox" <?php checked(true, $bedrooms); ?>>
                <label for="<?php echo $this->get_field_id('bedrooms'); ?>"><?php _e('Search by Bedrooms'); ?></label>
			</p>
            <p>
                <input id="<?php echo $this->get_field_id('price'); ?>" name="<?php echo $this->get_field_name('price'); ?>" type="checkbox" <?php checked(true, $price); ?> onclick="document.getElementById('<?php echo $this->get_field_id('price_details'); ?>').style.display=this.checked?'block':'none'">
                <label for="<?php echo $this->get_field_id('price'); ?>"><?php _e('Search by Price'); ?></label>
			</p>
            <div id="<?php echo $this->get_field_id('price_details'); ?>" <?php if (!$price) echo 'style="display:none"' ?>>
                <p>
                    <label for="<?php echo $this->get_field_id('from_price'); ?>"><?php _e('From Price:'); ?></label>
                    <input class="widefat" id="<?php echo $this->get_field_id('from_price'); ?>" name="<?php echo $this->get_field_name('from_price'); ?>" type="text" value="<?php echo $fromPrice; ?>"><br>
                </p>
                <p>
                    <label for="<?php echo $this->get_field_id('to_price'); ?>"><?php _e('To Price:'); ?></label>
                    <input class="widefat" id="<?php echo $this->get_field_id('to_price'); ?>" name="<?php echo $this->get_field_name('to_price'); ?>" type="text" value="<?php echo $toPrice; ?>"><br>
                </p>
                <p>
                    <label for="<?php echo $this->get_field_id('price_increment'); ?>"><?php _e('Price Increment:'); ?></label>
                    <input class="widefat" id="<?php echo $this->get_field_id('price_increment'); ?>" name="<?php echo $this->get_field_name('price_increment'); ?>" type="text" value="<?php echo $priceIncrement; ?>"><br>
                </p>
                <p>
                    <label for="<?php echo $this->get_field_id('currency_symbol'); ?>"><?php _e('Currency Symbol:'); ?></label>
                    <input class="widefat" id="<?php echo $this->get_field_id('currency_symbol'); ?>" name="<?php echo $this->get_field_name('currency_symbol'); ?>" type="text" value="<?php echo $currencySymbol; ?>"><br>
                </p>
            </div>
            <p>
                <input id="<?php echo $this->get_field_id('amenities'); ?>" name="<?php echo $this->get_field_name('amenities'); ?>" type="checkbox" <?php checked(true, $amenities); ?>>
                <label for="<?php echo $this->get_field_id('amenities'); ?>"><?php _e('Search by Amenities'); ?></label>
			</p>
            <p>
                <input id="<?php echo $this->get_field_id('name'); ?>" name="<?php echo $this->get_field_name('name'); ?>" type="checkbox" <?php checked(true, $name); ?>>
                <label for="<?php echo $this->get_field_id('name'); ?>"><?php _e('Search by Name or ID'); ?></label>
			</p>
		<?php
	}

    public function update($new_instance, $old_instance) {
        $instance = Array();
        $instance['title'] = strip_tags($new_instance['title']);
		$instance['button_text'] = strip_tags($new_instance['button_text']);
        $instance['horizontal'] = ($new_instance['horizontal'] == 'on');
        $instance['location'] = ($new_instance['location'] == 'on');
        $instance['bedrooms'] = ($new_instance['bedrooms'] == 'on');
        $instance['price'] = ($new_instance['price'] == 'on');
        $instance['from_price'] = strip_tags($new_instance['from_price']);
        $instance['to_price'] = strip_tags($new_instance['to_price']);
        $instance['price_increment'] = strip_tags($new_instance['price_increment']);
        $instance['currency_symbol'] = strip_tags($new_instance['currency_symbol']);
        $instance['amenities'] = ($new_instance['amenities'] == 'on');
        $instance['name'] = ($new_instance['name'] == 'on');
		return $instance;
	}

    public function widget($args, $instance) {
		global $wpdb;

        $pluginPath = plugin_dir_url(plugin_basename(__FILE__));
        $ld = 'p_lodgix'; // Localization domain
        $lang = substr(get_locale(), 0, 2);

        $tableProperties = $wpdb->prefix . 'lodgix_properties';
        $tableRules = $wpdb->prefix . 'lodgix_rules';
        $tableAmenities = $wpdb->prefix . 'lodgix_searchable_amenities';

		extract($args);

		$lodgixSettings = get_option('p_lodgix_options');

        $areas = $wpdb->get_results("SELECT DISTINCT area FROM $tableProperties WHERE area <> '' AND area IS NOT NULL");

        $limitBookingDaysAdvance = (int)$wpdb->get_var("SELECT MAX(limit_booking_days_advance) FROM $tableProperties");

        $dateFormat = $lodgixSettings['p_lodgix_date_format'];
        if ($dateFormat == '%m/%d/%Y') {
            $dateFormat = 'mm/dd/yy';
        } else if ($dateFormat == '%d/%m/%Y') {
            $dateFormat = 'dd/mm/yy';
        } else if ($dateFormat == '%m-%d-%Y') {
            $dateFormat = 'mm-dd-yy';
        } else if ($dateFormat == '%d-%m-%Y') {
            $dateFormat = 'dd-mm-yy';
        } else if ($dateFormat == '%d %b %Y') {
            $dateFormat = 'dd M yy';
        }

        $title = apply_filters('widget_title', empty($instance['title']) ? self::$DEFAULT_SETTINGS['title'] : esc_html($instance['title']));
        $button_text = apply_filters('button_text', empty($instance['button_text']) ? self::$DEFAULT_SETTINGS['button_text'] : esc_html($instance['button_text']));
        $horizontal = array_key_exists('horizontal', $instance) ? $instance['horizontal'] : self::$DEFAULT_SETTINGS['horizontal'];
        $showLocation = array_key_exists('location', $instance) ? $instance['location'] : self::$DEFAULT_SETTINGS['location'];
        $showBedrooms = array_key_exists('bedrooms', $instance) ? $instance['bedrooms'] : self::$DEFAULT_SETTINGS['bedrooms'];
        $showPrice = array_key_exists('price', $instance) ? $instance['price'] : self::$DEFAULT_SETTINGS['price'];
        $fromPrice = apply_filters('from_price', empty($instance['from_price']) ? self::$DEFAULT_SETTINGS['from_price'] : esc_html($instance['from_price']));
        $toPrice = apply_filters('to_price', empty($instance['to_price']) ? self::$DEFAULT_SETTINGS['to_price'] : esc_html($instance['to_price']));
        $priceIncrement = apply_filters('price_increment', empty($instance['price_increment']) ? self::$DEFAULT_SETTINGS['price_increment'] : esc_html($instance['price_increment']));
        if (!empty($instance['currency_symbol'])) {
            $currencySymbol = esc_html($instance['currency_symbol']);
        } else {
            $properties = $wpdb->get_results("SELECT currency_symbol FROM $tableProperties LIMIT 1");
            if ($properties) {
                $currencySymbol = esc_html($properties[0]->currency_symbol);
            } else {
                $currencySymbol = self::$DEFAULT_SETTINGS['currency_symbol'];
            }
        }
        $currencySymbol = apply_filters('currency_symbol', $currencySymbol);
        $showAmenities = array_key_exists('amenities', $instance) ? $instance['amenities'] : self::$DEFAULT_SETTINGS['amenities'];
        $showName = array_key_exists('name', $instance) ? $instance['name'] : self::$DEFAULT_SETTINGS['name'];

        echo $before_widget;

        if (!$horizontal) {
            echo $before_title . __($title, $ld) . $after_title;
        }

        if ($lang != 'en') {
            echo '<script src="' . $pluginPath . 'js/i18n/datepicker-' . $lang. '.js"></script>';
        }

        ?>
            <div class="ldgxRentalSearchWidget <?php echo $horizontal ? 'ldgxRentalSearchWidgetHorizontal' : 'ldgxRentalSearchWidgetVertical'; ?>">
                <form id="ldgxRentalSearchForm" method="post" action="<?php echo get_permalink((int)$lodgixSettings['p_lodgix_search_rentals_page_' . $lang]); ?>">
                    <div class="ldgxRentalSearchContainer">
                        <div class="ldgxRentalSearchDiv ldgxRentalSearchDivArrival">
                            <input type="text" id="ldgxRentalSearchDatepicker" name="lodgix-custom-search-datepicker" value="<?php echo htmlspecialchars($_POST['lodgix-custom-search-datepicker']); ?>" placeholder="<?php echo __('Arriving', $ld); ?>" onchange="lodgixRentalSearch()" readonly>
        					<input type="hidden" id="ldgxRentalSearchArrival" name="lodgix-custom-search-arrival" value="<?php echo htmlspecialchars($_POST['lodgix-custom-search-arrival']); ?>">
                        </div>
                        <div class="ldgxRentalSearchDiv ldgxRentalSearchDivNights">
                            <select id="ldgxRentalSearchNights" name="lodgix-custom-search-nights" onchange="lodgixRentalSearch()">
                                <?php
                                    $minNights = $wpdb->get_var("SELECT MIN(min_nights) FROM $tableRules");
                                    if ($minNights < 1) {
                                        $minNights = 1;
                                    }
                                    if (isset($_POST['lodgix-custom-search-nights'])) {
                                        $value = (int)$_POST['lodgix-custom-search-nights'];
                                        for ($i = $minNights; $i < 100; $i++) {
                                            $selected = $value == $i ? 'selected' : '';
                                            echo "<option value='$i' $selected>$i " . __($i > 1 ? 'nights' : 'night', $ld) . "</option>";
                                        }
                                    } else {
                                        echo '<option value="" selected>' . __('Nights', $ld) . '</option>';
                                        for ($i = $minNights; $i < 100; $i++) {
                                            echo "<option value='$i'>$i " . __($i > 1 ? 'nights' : 'night', $ld) . "</option>";
                                        }
                                    }
                                ?>
                            </select>
                        </div>
                        <?php
                            if ($showLocation) {
                                ?>
                                <div class="ldgxRentalSearchDiv ldgxRentalSearchDivArea">
                                    <select id="ldgxRentalSearchArea" name="lodgix-custom-search-area" onchange="lodgixRentalSearch()">
                                        <?php
                                            if (isset($_POST['lodgix-custom-search-area'])) {
                                                $value = $_POST['lodgix-custom-search-area'];
                                                if ($value == 'ALL_AREAS') {
                                                    echo '<option value="ALL_AREAS" selected>' . __('All Areas', $ld) . '</option>';
                                                    foreach ($areas as $area) {
                                                        echo "<option value='$area->area'>$area->area</option>";
                                                    }
                                                } else {
                                                    echo '<option value="ALL_AREAS">' . __('All Areas', $ld) . '</option>';
                                                    foreach ($areas as $area) {
                                                        $selected = $value == $area->area ? 'selected' : '';
                                                        echo "<option value='$area->area' $selected>$area->area</option>";
                                                    }
                                                }
                                            } else {
                                                echo '<option value="" selected>' . __('Location', $ld) . '</option>';
                                                echo '<option value="ALL_AREAS">' . __('All Areas', $ld) . '</option>';
                                                foreach ($areas as $area) {
                                                    echo "<option value='$area->area'>$area->area</option>";
                                                }
                                            }
                                        ?>
                                    </select>
                                </div>
                                <?php
                            }
                            if ($showBedrooms) {
                                ?>
                                <div class="ldgxRentalSearchDiv ldgxRentalSearchDivBedrooms">
                                    <select id="ldgxRentalSearchBedrooms" name="lodgix-custom-search-bedrooms" onchange="lodgixRentalSearch()">
                                        <?php
                                            $minRooms = (int)$wpdb->get_var("SELECT MIN(bedrooms) FROM $tableProperties");
                                            $maxRooms = (int)$wpdb->get_var("SELECT MAX(bedrooms) FROM $tableProperties");
                                            if (isset($_POST['lodgix-custom-search-bedrooms'])) {
                                                $value = $_POST['lodgix-custom-search-bedrooms'];
                                                if ($value == 'ANY') {
                                                    echo '<option value="ANY" selected>' . __('Any Bedrooms', $ld) . '</option>';
                                                    if ($minRooms == 0) {
                                                        echo '<option value="0">' . __('Studio', $ld) . '</option>';
                                                    }
                                                    for ($i = 1; $i <= $maxRooms; $i++) {
                                                        echo "<option value='$i'>$i " . __($i > 1 ? 'bedrooms' : 'bedroom', $ld) . "</option>";
                                                    }
                                                } else {
                                                    echo '<option value="ANY">' . __('Any Bedrooms', $ld) . '</option>';
                                                    if ($minRooms == 0) {
                                                        if ($value == '0') {
                                                            echo '<option value="0" selected>' . __('Studio', $ld) . '</option>';
                                                        } else {
                                                            echo '<option value="0">' . __('Studio', $ld) . '</option>';
                                                        }
                                                    }
                                                    $value = (int)$value;
                                                    for ($i = 1; $i <= $maxRooms; $i++) {
                                                        $selected = $value == $i ? 'selected' : '';
                                                        echo "<option value='$i' $selected>$i " . __($i > 1 ? 'bedrooms' : 'bedroom', $ld) . "</option>";
                                                    }
                                                }
                                            } else {
                                                echo '<option value="" selected>' . __('Bedrooms', $ld) . '</option>';
                                                echo '<option value="ANY">' . __('Any Bedrooms', $ld) . '</option>';
                                                if ($minRooms == 0) {
                                                    echo '<option value="0">' . __('Studio', $ld) . '</option>';
                                                }
                                                for ($i = 1; $i <= $maxRooms; $i++) {
                                                    echo "<option value='$i'>$i " . __($i > 1 ? 'bedrooms' : 'bedroom', $ld) . "</option>";
                                                }
                                            }
                                        ?>
                                    </select>
                                </div>
                                <?php
                            }
                            if ($showPrice) {
                                ?>
                                <div class="ldgxRentalSearchDiv ldgxRentalSearchDivDailyPriceFrom">
                                    <select id="ldgxRentalSearchDailyPriceFrom" name="lodgix-custom-search-daily-price-from" onchange="lodgixRentalSearch()">
                                        <?php
                                            if (isset($_POST['lodgix-custom-search-daily-price-from'])) {
                                                $value = (int)$_POST['lodgix-custom-search-daily-price-from'];
                                                echo '<option value="0" ' . ($value == 0 ? 'selected' : '')
                                                    . '>' . __('From Any Price', $ld) . '</option>';
                                                for ($i = $fromPrice; $i <= $toPrice; $i += $priceIncrement) {
                                                    echo '<option value="' . $i . '" '
                                                        . ($value == $i ? 'selected' : '') . '>' . __('From', $ld)
                                                        . ' ' . $currencySymbol . $i . ' ' . __('per nt', $ld)
                                                        . '</option>';
                                                }
                                            } else {
                                                echo '<option value="" selected>' . __('Daily Price From', $ld)
                                                    . '</option>';
                                                echo '<option value="0">' . __('From Any Price', $ld) . '</option>';
                                                for ($i = $fromPrice; $i <= $toPrice; $i += $priceIncrement) {
                                                    echo '<option value="' . $i . '">' . __('From', $ld) . ' '
                                                        . $currencySymbol . $i . ' ' . __('per nt', $ld) . '</option>';
                                                }
                                            }
                                        ?>
                                    </select>
                                </div>
                                <div class="ldgxRentalSearchDiv ldgxRentalSearchDivDailyPriceTo">
                                    <select id="ldgxRentalSearchDailyPriceTo" name="lodgix-custom-search-daily-price-to" onchange="lodgixRentalSearch()">
                                        <?php
                                            if (isset($_POST['lodgix-custom-search-daily-price-to'])) {
                                                $value = (int)$_POST['lodgix-custom-search-daily-price-to'];
                                                echo '<option value="0" ' . ($value == 0 ? 'selected' : '')
                                                    . '>' . __('To Any Price', $ld) . '</option>';
                                                for ($i = $fromPrice; $i <= $toPrice; $i += $priceIncrement) {
                                                    echo '<option value="' . $i . '" '
                                                        . ($value == $i ? 'selected' : '') . '>' . __('To', $ld) . ' '
                                                        . $currencySymbol . $i . ' ' . __('per nt', $ld) . '</option>';
                                                }
                                            } else {
                                                echo '<option value="" selected>' . __('Daily Price To', $ld) . '</option>';
                                                echo '<option value="0">' . __('To Any Price', $ld) . '</option>';
                                                for ($i = $fromPrice; $i <= $toPrice; $i += $priceIncrement) {
                                                    echo '<option value="' . $i . '">' . __('To', $ld) . ' '
                                                        . $currencySymbol . $i . ' ' . __('per nt', $ld) . '</option>';
                                                }
                                            }
                                        ?>
                                    </select>
                                </div>
                                <?php
                            }
                            if ($showAmenities) {
                                ?>
                                <div class="ldgxRentalSearchDiv ldgxRentalSearchDivAmenities">
                                    <?php
                                        $values = isset($_POST['lodgix-custom-search-amenity']) ? $_POST['lodgix-custom-search-amenity'] : array();
                                        $amenities = $wpdb->get_results("SELECT DISTINCT * FROM $tableAmenities");
                                        $i = 0;
                                        foreach ($amenities as $amenity) {
                                            $amenityName = trim($amenity->description);
                                            $amenityNameTranslated = LodgixTranslate::translateAmenity($amenityName, $lang);
                                            $checked = in_array($amenityName, $values) ? 'checked' : '';
                                            echo "
                                                <div class='ldgxRentalSearchAmenity'>
                                                    <input type='checkbox' id='ldgxRentalSearchAmenity$i' name='lodgix-custom-search-amenity[]' value='$amenityName' $checked onclick='lodgixRentalSearch()'>
                                                    <label for='ldgxRentalSearchAmenity$i'>$amenityNameTranslated</label>
                                                </div>
                                            ";
                                            $i++;
                                        }
                                    ?>
                                </div>
                                <?php
                            }
                            if ($showName) {
                                ?>
                                <div class="ldgxRentalSearchDiv ldgxRentalSearchDivId">
                                    <input type="text" id="ldgxRentalSearchId" name="lodgix-custom-search-id"
                                           placeholder="<?php echo __('Property Name or ID', $ld); ?>"
                                           onkeyup="lodgixRentalSearch()"
                                           value="<?php echo htmlspecialchars($_POST['lodgix-custom-search-id']); ?>">
                                </div>
                                <?php
                            }
                        ?>
                        <div class="ldgxRentalSearchDiv ldgxRentalSearchDivSubmit">
                            <button id="ldgxRentalSearchSubmit"><?php echo __($button_text, $ld); ?></button>
                        </div>
                    </div>
                </form>
            </div>
            <script>
                (function($) {
                    'use strict';

                    $.templates({
                        lodgixRentalSearchResultsTooltip: ['<div class="ldgxRentalSearchResultsTooltipContent">{{:numResults}} <?php echo __('Properties Found', $ld); ?></div>'].join('')
                    });

                    window.lodgixRentalSearchTooltip = new LodgixTooltip();
                    window.lodgixRentalSearchTooltip.el().addClass('ldgxRentalSearchResultsTooltip');

                    function hideTooltip() {
                        window.lodgixRentalSearchTooltip.hide();
                    }

                    $(window).resize(hideTooltip);

                    window.lodgixRentalSearch = function() {
                        if (!$('#ldgxRentalSearchArrival').val()) {
                            var tomorrow = new Date();
                            tomorrow.setDate(tomorrow.getDate() + 1);
                            jQueryLodgix('#ldgxRentalSearchDatepicker').datepicker('setDate', tomorrow);
                        }
                        $('#ldgxRentalSearchNights option[value=""]').remove();
                        $('#ldgxRentalSearchArea option[value=""]').remove();
                        $('#ldgxRentalSearchBedrooms option[value=""]').remove();
                        $('#ldgxRentalSearchDailyPriceFrom option[value=""]').remove();
                        $('#ldgxRentalSearchDailyPriceTo option[value=""]').remove();
                        if (parseInt($('#ldgxRentalSearchDailyPriceFrom').val()) > parseInt($('#ldgxRentalSearchDailyPriceTo').val())) {
                            $('#ldgxRentalSearchDailyPriceTo option[value="0"]').prop('selected', true);
                        }
                        $('#ldgxRentalSearchSubmit').addClass('ldgxRainbowAnimation');
                        $('#ldgxRentalSearchForm').ajaxSubmit({
                            url: '<?php echo get_bloginfo('wpurl'); ?>/wp-admin/admin-ajax.php',
                            data: {
                                'action': 'p_lodgix_custom_search'
                            },
                            dataType: 'json',
                            success: function(response) {
                                if (response) {
                                    var submitButton = $('.ldgxRentalSearchDivSubmit');
                                    hideTooltip();
                                    window.lodgixRentalSearchTooltip.show({
                                        trigger: submitButton,
                                        template: 'lodgixRentalSearchResultsTooltip',
                                        params: {
                                            numResults: response.num_results || 0
                                        },
                                        touch: true,
                                        onTouch: function() {
                                            window.lodgixRentalSearchTooltip.hide();
                                        },
                                        onBeforeHide: function() {
                                            submitButton.off({
                                                mouseover: hideTooltip,
                                                click: hideTooltip
                                            });
                                            window.lodgixRentalSearchTooltip.el().off({
                                                mouseover: hideTooltip
                                            });
                                        }
                                    });
                                    submitButton.on({
                                        mouseover: hideTooltip,
                                        click: hideTooltip
                                    });
                                    window.lodgixRentalSearchTooltip.el().on({
                                        mouseover: hideTooltip
                                    });

                                    var min_nights = response.min_nights || 1;
                                    var selectbox = $('#ldgxRentalSearchNights');
                                    var selected = parseInt(selectbox.val());
                                    if (isNaN(selected) || selected < min_nights) {
                                        selected = min_nights;
                                    }
                                    var options = [];
                                    for (var i = min_nights; i < 100; i++) {
                                        options.push('<option value="');
                                        options.push(i);
                                        options.push('">');
                                        options.push(i);
                                        if (i > 1) {
                                            options.push(' <?php echo __('nights', $ld); ?>');
                                        } else {
                                            options.push(' <?php echo __('night', $ld); ?>');
                                        }
                                        options.push('</option>');
                                    }
                                    selectbox.empty().append(options.join(''));
                                    $('#ldgxRentalSearchNights option[value="' + selected + '"]').prop('selected', true);
                                }
                            },
                            complete: function() {
                                $('#ldgxRentalSearchSubmit').removeClass('ldgxRainbowAnimation');
                            }
                        });
                    };

                    var maxDate = null;
                    var limitDays = parseInt('<?php echo $limitBookingDaysAdvance; ?>');
                    if (!isNaN(limitDays) && limitDays > 0) {
                        maxDate = new Date();
                        maxDate.setDate(maxDate.getDate() + limitDays);
                    }

                    $(document).ready(function() {
                        var dateFormat = '<?php echo $dateFormat; ?>';
                        var datepickerEl = jQueryLodgix('#ldgxRentalSearchDatepicker');
                        datepickerEl.datepicker({
                                showOn: 'both',
                                buttonImage: '<?php echo $pluginPath; ?>images/calendar.png',
                                buttonImageOnly: true,
                                dateFormat: dateFormat,
                                altField: '#ldgxRentalSearchArrival',
                                altFormat: 'yy-mm-dd',
                                minDate: 0,
                                maxDate: maxDate,
                                beforeShow: function() {
                                    setTimeout(function() {
                                        jQueryLodgix('#lodgix-datepicker-div').css('z-index', 99999999999999);
                                    }, 0);
                                }
                            }<?php if ($lang != 'en') { echo ', jQueryLodgix.datepicker.regional["' . $lang. '"]'; } ?>)
                            .next('.lodgix-datepicker-trigger').addClass('ldgxRentalSearchDatepickerTrigger');

                        if (maxDate) {
                            var date = jQueryLodgix.datepicker.parseDate(dateFormat, datepickerEl.val());
                            if (date > maxDate) {
                                jQueryLodgix('#ldgxRentalSearchDatepicker').datepicker('setDate', maxDate);
                            }
                        }
                    });

                }(jQLodgix));
            </script>
        <?php

		echo $after_widget;
	}
}

function lodgixRegisterWidgetRentalSearch2() {
    register_widget('LodgixWidgetRentalSearch2');
}

add_action('widgets_init', 'lodgixRegisterWidgetRentalSearch2');
